(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     19076,        577]
NotebookOptionsPosition[     17509,        527]
NotebookOutlinePosition[     18112,        549]
CellTagsIndexPosition[     18069,        546]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Inverse Compton Scattering ***",
 FontSize->24]], "Title",
 CellChangeTimes->{
  3.6701144841567383`*^9, {3.6701160347139177`*^9, 3.670116035211981*^9}, 
   3.67019424558773*^9, 3.6702007410004807`*^9, 3.670364120976672*^9, {
   3.670364408564468*^9, 3.670364409541194*^9}, {3.6715506748104362`*^9, 
   3.671550682835517*^9}}],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"$Line", ":=", "1"}]}], "Input",
 CellChangeTimes->{{3.6702014732074833`*^9, 3.670201485516623*^9}, {
  3.67020152205274*^9, 3.670201530563534*^9}, {3.670284554270102*^9, 
  3.670284568658255*^9}}],

Cell[TextData[{
 StyleBox["Problem",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.67011569685713*^9, 3.6701156986701317`*^9}, 
   3.6702007410009747`*^9}],

Cell[TextData[{
 "Consider an interstellar cloud of non-relativistic electrons at a \
temperature T. A large quantity of photons from the Cosmic Microwave \
Background with energies h\[Nu] << kT flows continuously through the cloud. \
The cloud is optically thick to inverse Compton scattering (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "com"], TraditionalForm]]],
 " >> 1) but has shallow optical depth to absorption (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "abs"], TraditionalForm]]],
 " << 1). Inverse Compton scattering causes the photon energy to increase \
greatly so that the final energy is much greater than the initial energy (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "f"], TraditionalForm]]],
 " >> ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "i"], TraditionalForm]]],
 "). Increasing ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "com"], TraditionalForm]]],
 " up to a critical value causes a rapid increase in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "f"], TraditionalForm]]],
 ", where the inverse Comptonization process saturates. Find an expression \
for the critical value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "com"], TraditionalForm]]],
 ". Use cgs units."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670114881468607*^9, 3.6701148979074306`*^9}, {
   3.6701149837486563`*^9, 3.670115072697233*^9}, {3.6701155580988483`*^9, 
   3.670115668844935*^9}, {3.670115723227726*^9, 3.670115723749885*^9}, {
   3.6701160387538443`*^9, 3.6701160390579977`*^9}, {3.670194286929597*^9, 
   3.670194288420822*^9}, 3.670200741003162*^9, {3.6703642354986553`*^9, 
   3.67036423730779*^9}, 3.67036427189014*^9, {3.671550697504307*^9, 
   3.671550705147614*^9}, {3.6715507470655813`*^9, 3.671550826590035*^9}, {
   3.671550858364943*^9, 3.671551026771056*^9}, {3.679954266469878*^9, 
   3.6799545274872503`*^9}, {3.679955658245924*^9, 3.67995567577207*^9}, 
   3.679955718495719*^9, {3.6799573965030947`*^9, 3.679957403000492*^9}, 
   3.683499123959989*^9},
 TextAlignment->Left,
 TextJustification->1,
 LineSpacing->{1, 3}],

Cell[TextData[{
 "\n",
 StyleBox["Hints",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.670117651601288*^9, 3.670117655086029*^9}, 
   3.670200741003615*^9}],

Cell[TextData[{
 "Calculate ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "f"], TraditionalForm]]],
 " as a function of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "i"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "com"], TraditionalForm]]],
 ", and T.\nFind an approximate expression for the critical value ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "crit"], TraditionalForm]]],
 ".\nNote that saturation occurs when ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h\[Nu]", "f"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "\[Tilde]4kT."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.6701159257090197`*^9, 3.670116019553904*^9}, {
   3.6701161674607077`*^9, 3.6701162053537273`*^9}, {3.670194372759892*^9, 
   3.670194374153833*^9}, 3.670200741004274*^9, 3.6703642795409603`*^9, {
   3.671551055868824*^9, 3.67155108504362*^9}, {3.671551126159314*^9, 
   3.671551146883251*^9}, {3.671551177435107*^9, 3.671551207833632*^9}, {
   3.6799546009706*^9, 3.6799546296249857`*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Useful Equations:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.670116586419656*^9, 3.67011659119991*^9}, {
   3.6701948694882393`*^9, 3.670194893362927*^9}, {3.670195019345068*^9, 
   3.670195063029786*^9}, 3.670195495956923*^9, 3.670195558720975*^9, 
   3.670195654585294*^9, {3.6701961617449093`*^9, 3.670196168444582*^9}, {
   3.6701963733751507`*^9, 3.670196388469788*^9}, 3.670196432118155*^9, 
   3.6702007410289583`*^9, {3.670201009142297*^9, 3.670201011794355*^9}, 
   3.6702836215572166`*^9, 3.671551492807332*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]", 
    FormBox[
     RowBox[{"(", "h\[Nu]", ")"}],
     TraditionalForm]}], "=", 
   RowBox[{"h\[Nu]", "*", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", "*", "k", "*", "T"}], 
       RowBox[{"m", "*", 
        SuperscriptBox["c", "2"]}]], "-", 
      FractionBox["h\[Nu]", 
       RowBox[{"m", "*", 
        SuperscriptBox["c", "2"]}]]}], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "energy", " ", "transferred", " ", "to", " ", "a", " ", 
    "photon", " ", "of", " ", "energy", " ", "\[Epsilon]"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"d", 
     RowBox[{"(", "h\[Nu]", ")"}]}], "dN"], "\[Tilde]", 
   RowBox[{"h\[Nu]", "*", 
    RowBox[{"(", 
     FractionBox[
      RowBox[{"4", "*", "k", "*", "T"}], 
      RowBox[{"m", "*", 
       SuperscriptBox["c", "2"]}]], ")"}]}]}], " ", 
  RowBox[{"(*", 
   RowBox[{"for", " ", "h\[Nu]", " ", 
    RowBox[{"<<", " ", "4"}], "kT"}], "*)"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   FractionBox[
    SubscriptBox["h\[Nu]", "N"], 
    SubscriptBox["h\[Nu]", "i"]], "\[Tilde]", 
   SuperscriptBox["h\[Nu]", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"4", "*", "k", "*", "T"}], 
       RowBox[{"m", "*", 
        SuperscriptBox["c", "2"]}]], ")"}], "*", "N"}]]}], "  ", 
  RowBox[{"(*", 
   RowBox[{"after", " ", "N", " ", "scatterings"}], "*)"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"N", "=", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox["\[Tau]", "com"], ")"}], "2"],
    TraditionalForm]}], "  ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "number", " ", "of", " ", "scatterings", " ", "for", " ", "optical", " ", 
     "depth"}], ">>", "1"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  FormBox[
   SubscriptBox["h\[Nu]", "f"],
   TraditionalForm], "\[Tilde]", 
  RowBox[{"4", "*", "k", "*", "T", "  ", 
   RowBox[{"(*", 
    RowBox[{"condition", " ", "for", " ", "saturation"}], "*)"}]}]}]}], "Text",\

 CellFrame->0.5,
 CellChangeTimes->{{3.670024577191853*^9, 3.670024579538969*^9}, {
   3.670024624107288*^9, 3.670024894294174*^9}, {3.670024943774929*^9, 
   3.670024971738525*^9}, {3.67002514435083*^9, 3.670025147795293*^9}, {
   3.6700252139218063`*^9, 3.67002521575095*^9}, 3.6700253017518463`*^9, 
   3.67011654558143*^9, {3.670116606621243*^9, 3.6701166080987053`*^9}, {
   3.6701169543239822`*^9, 3.6701169620530376`*^9}, {3.670118158526649*^9, 
   3.6701181622876673`*^9}, {3.670118408707041*^9, 3.6701184124213877`*^9}, 
   3.6701184475656643`*^9, 3.670200741029684*^9, 3.670201065964548*^9, {
   3.670282905989079*^9, 3.670282965091505*^9}, {3.670283056356124*^9, 
   3.670283075180468*^9}, {3.6702831115502872`*^9, 3.670283427329583*^9}, 
   3.670285389231699*^9, 3.670364303827129*^9, {3.6715536619990892`*^9, 
   3.671553705728323*^9}, {3.67155373896727*^9, 3.671553860048362*^9}, {
   3.671553900088274*^9, 3.671553945936331*^9}, {3.671553990618765*^9, 
   3.671554018720583*^9}, {3.6715540547988987`*^9, 3.671554080232519*^9}, {
   3.679954654369546*^9, 3.679954697060087*^9}, {3.679954741547658*^9, 
   3.679954830989172*^9}, 3.679954880576639*^9, 3.679954912694618*^9, {
   3.67995574420236*^9, 3.679955744941444*^9}}],

Cell[TextData[{
 StyleBox["\nSolution",
  FontWeight->"Bold"],
 " :\n"
}], "Text",
 CellChangeTimes->{{3.6702835139010363`*^9, 3.670283526046495*^9}, {
  3.670283585590893*^9, 3.670283603757029*^9}, {3.670283793166462*^9, 
  3.6702838015719423`*^9}, {3.670285991308682*^9, 3.6702859926447573`*^9}, {
  3.670364313853258*^9, 3.670364321300959*^9}, {3.6715514855222197`*^9, 
  3.6715514859034*^9}}],

Cell[TextData[{
 "The energy transferred to a photon of energy ",
 Cell[BoxData[
  FormBox["h\[Nu]", TraditionalForm]]],
 " is"
}], "Text",
 CellChangeTimes->{
  3.671551553347372*^9, {3.671551583936861*^9, 3.671551583938396*^9}, {
   3.679954949507577*^9, 3.679954953105852*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]", 
   FormBox[
    RowBox[{"(", "h\[Nu]", ")"}],
    TraditionalForm]}], "=", 
  RowBox[{"h\[Nu]", "*", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"4", "*", "k", "*", "T"}], 
      RowBox[{"m", "*", 
       SuperscriptBox["c", "2"]}]], "-", 
     FractionBox["h\[Nu]", 
      RowBox[{"m", "*", 
       SuperscriptBox["c", "2"]}]]}], ")"}]}]}]], "Text",
 CellChangeTimes->{{3.671551610015379*^9, 3.671551728441139*^9}, 
   3.679954978392206*^9, {3.67995581094361*^9, 3.679955813705666*^9}}],

Cell["\<\
If h\[Nu] << 4kT, the electrons are nonrelativistic, and the following \
approximate differential holds:\
\>", "Text",
 CellChangeTimes->{{3.671551749029875*^9, 3.671551763915803*^9}, 
   3.6799549969701757`*^9, {3.679955924747312*^9, 3.679955957503929*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"d", 
    RowBox[{"(", "h\[Nu]", ")"}]}], "dN"], "\[Tilde]", 
  RowBox[{"h\[Nu]", "*", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"4", "*", "k", "*", "T"}], 
     RowBox[{"m", "*", 
      SuperscriptBox["c", "2"]}]], ")"}]}]}]], "Text",
 CellChangeTimes->{{3.671551820005682*^9, 3.671551860507303*^9}, {
  3.679955001358673*^9, 3.679955007469043*^9}}],

Cell["\<\
where dN is the differential number of scatterings. After N scatterings :\
\>", "Text",
 CellChangeTimes->{{3.671551890609366*^9, 3.671551899038653*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SubscriptBox["h\[Nu]", "f"], 
   SubscriptBox["h\[Nu]", "i"]], "\[Tilde]", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      RowBox[{"4", "*", "k", "*", "T"}], 
      RowBox[{"m", "*", 
       SuperscriptBox["c", "2"]}]], ")"}], "*", "N"}]]}]], "Text",
 CellChangeTimes->{{3.671551944732946*^9, 3.671552071151729*^9}, {
  3.679955049840126*^9, 3.679955054824099*^9}, {3.679956025368923*^9, 
  3.679956027013699*^9}}],

Cell[TextData[{
 "for ",
 Cell[BoxData[
  SubscriptBox["h\[Nu]", "f"]],
  CellChangeTimes->{{3.671551944732946*^9, 3.671552071151729*^9}}],
 " << 4*k*T, where ",
 Cell[BoxData[
  SubscriptBox["h\[Nu]", "i"]],
  CellChangeTimes->{{3.671551944732946*^9, 3.671552071151729*^9}}],
 " is the initial energy of a photon.\n\nWhere optical depth is much greater \
than 1, a typical photon scatters approximately",
 Cell[BoxData[
  FormBox[
   RowBox[{"  ", 
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox["\[Tau]", "com"], ")"}], "2"]}], TraditionalForm]]],
 " times before escaping the cloud because of the random-walk pattern of the \
Compton scattering. Setting N = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     SubscriptBox["\[Tau]", "com"], ")"}], "2"], TraditionalForm]]],
 " yields"
}], "Text",
 CellChangeTimes->{{3.671552108609643*^9, 3.671552162965352*^9}, {
   3.67155220155096*^9, 3.6715523418782263`*^9}, 3.671552398001561*^9, {
   3.6799550637124*^9, 3.6799550949036627`*^9}, {3.6799552630311203`*^9, 
   3.679955263031274*^9}, {3.679955987697439*^9, 3.679955990075973*^9}, {
   3.679956165505947*^9, 3.679956169023409*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SubscriptBox["h\[Nu]", "f"], 
   SubscriptBox["h\[Nu]", "i"]], "\[Tilde]", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"(", 
     FractionBox[
      RowBox[{"4", "*", "k", "*", "T"}], 
      RowBox[{"m", "*", 
       SuperscriptBox["c", "2"]}]], ")"}], "*", 
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox["\[Tau]", "com"], ")"}], "2"]}]]}]], "Text",
 CellChangeTimes->{{3.671552382704487*^9, 3.67155240257554*^9}, {
   3.6799551183839693`*^9, 3.679955139766521*^9}, 3.679955241964518*^9}],

Cell["Saturation occurs when", "Text",
 CellChangeTimes->{{3.671552662958418*^9, 3.671552667664542*^9}, 
   3.6799552191763477`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["h\[Nu]", "f"], "\[Tilde]", 
  RowBox[{"4", "*", "k", "*", "T"}]}]], "Text",
 CellChangeTimes->{{3.671552712316618*^9, 3.6715527345622787`*^9}, 
   3.679955278246702*^9}],

Cell["Therefore, ", "Text",
 CellChangeTimes->{{3.67155276406633*^9, 3.671552764078477*^9}, {
   3.679956211495226*^9, 3.679956223129714*^9}, 3.679956265958214*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"4", "*", "k", "*", "T"}], 
   SubscriptBox["h\[Nu]", "i"]], "\[Tilde]", 
  SuperscriptBox["\[ExponentialE]", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"4", "*", "k", "*", "T"}], 
       RowBox[{"m", "*", 
        SuperscriptBox["c", "2"]}]], ")"}], "*", 
     SuperscriptBox[
      RowBox[{"(", 
       SubscriptBox["\[Tau]", "crt"], ")"}], "2"]}]]]}]], "Text",
 CellChangeTimes->{{3.6715528655064497`*^9, 3.671552919764641*^9}, {
  3.679955313259797*^9, 3.679955360251939*^9}}],

Cell["\<\
where the optical depth (\[Tau]) has the critical value. Take the natural log \
of both sides:\
\>", "Text",
 CellChangeTimes->{{3.671553056134265*^9, 3.6715530733050737`*^9}, {
  3.6799554041003*^9, 3.679955446281787*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    FractionBox[
     RowBox[{"4", "*", "k", "*", "T"}], 
     RowBox[{"m", "*", 
      SuperscriptBox["c", "2"]}]], ")"}], "*", 
   FormBox[
    SuperscriptBox[
     RowBox[{"(", 
      SubscriptBox["\[Tau]", "crit"], ")"}], "2"],
    TraditionalForm]}], "=", 
  RowBox[{"Log", "[", 
   FractionBox[
    RowBox[{"4", "*", "k", "*", "T"}], 
    SubscriptBox["h\[Nu]", "i"]], "]"}]}]], "Text",
 CellChangeTimes->{{3.671553182471623*^9, 3.671553183648323*^9}, {
  3.6715532144925613`*^9, 3.67155329026215*^9}, {3.679955458282167*^9, 
  3.6799554684304523`*^9}}],

Cell[TextData[{
 "Solve for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "crit"], TraditionalForm]],
  CellChangeTimes->{{3.671553182471623*^9, 3.671553183648323*^9}, {
   3.6715532144925613`*^9, 3.67155329026215*^9}}],
 " :"
}], "Text",
 CellChangeTimes->{{3.671553321997357*^9, 3.671553337634897*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      FractionBox[
       RowBox[{"4", "*", "k", "*", "T"}], 
       RowBox[{"m", "*", 
        SuperscriptBox["c", "2"]}]], ")"}], "*", 
     FormBox[
      SuperscriptBox[
       RowBox[{"(", 
        SubscriptBox["\[Tau]", "crit"], ")"}], "2"],
      TraditionalForm]}], "==", 
    RowBox[{"Log", "[", 
     FractionBox[
      RowBox[{"4", "*", "k", "*", "T"}], 
      SubscriptBox["h\[Nu]", "i"]], "]"}]}], ",", 
   SubscriptBox["\[Tau]", "crit"]}], "]"}]], "Input",
 CellChangeTimes->{{3.6715533671264133`*^9, 3.6715534004392357`*^9}, 
   3.679955492466591*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Tau]", "crit"], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"c", " ", 
        SqrtBox["m"], " ", 
        SqrtBox[
         RowBox[{"Log", "[", 
          FractionBox[
           RowBox[{"4", " ", "k", " ", "T"}], 
           SubscriptBox["h\[Nu]", "i"]], "]"}]]}], 
       RowBox[{"2", " ", 
        SqrtBox["k"], " ", 
        SqrtBox["T"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Tau]", "crit"], "\[Rule]", 
     FractionBox[
      RowBox[{"c", " ", 
       SqrtBox["m"], " ", 
       SqrtBox[
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{"4", " ", "k", " ", "T"}], 
          SubscriptBox["h\[Nu]", "i"]], "]"}]]}], 
      RowBox[{"2", " ", 
       SqrtBox["k"], " ", 
       SqrtBox["T"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.671553386056922*^9, 3.671553403374104*^9}, 
   3.679955498720069*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Tau]", "crit"], "=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{"c", " ", 
     SqrtBox["m"], " ", 
     SqrtBox[
      RowBox[{"Log", "[", 
       FractionBox[
        RowBox[{"4", " ", "k", " ", "T"}], 
        SubscriptBox["h\[Nu]", "i"]], "]"}]]}], 
    RowBox[{"2", " ", 
     SqrtBox["k"], " ", 
     SqrtBox["T"]}]]}]}]], "Text",
 CellChangeTimes->{{3.679955583055916*^9, 3.679955589139654*^9}}]
}, Open  ]]
},
WindowSize->{740, 599},
WindowMargins->{{Automatic, 267}, {-8, Automatic}},
Magnification->1.25,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 350, 6, 85, "Title"],
Cell[932, 30, 298, 5, 57, "Input"],
Cell[1233, 37, 171, 6, 37, "Text"],
Cell[1407, 45, 2128, 50, 282, "Text"],
Cell[3538, 97, 173, 7, 61, "Text"],
Cell[3714, 106, 1089, 31, 112, "Text"],
Cell[4806, 139, 570, 11, 61, "Text"],
Cell[5379, 152, 3380, 89, 371, "Text"],
Cell[8762, 243, 396, 9, 106, "Text"],
Cell[9161, 254, 280, 8, 46, "Text"],
Cell[9444, 264, 560, 17, 75, "Text"],
Cell[10007, 283, 268, 5, 76, "Text"],
Cell[10278, 290, 406, 12, 75, "Text"],
Cell[10687, 304, 163, 3, 46, "Text"],
Cell[10853, 309, 500, 14, 81, "Text"],
Cell[11356, 325, 1166, 30, 175, "Text"],
Cell[12525, 357, 560, 16, 81, "Text"],
Cell[13088, 375, 132, 2, 46, "Text"],
Cell[13223, 379, 209, 5, 45, "Text"],
Cell[13435, 386, 164, 2, 46, "Text"],
Cell[13602, 390, 592, 17, 91, "Text"],
Cell[14197, 409, 233, 5, 76, "Text"],
Cell[14433, 416, 611, 19, 75, "Text"],
Cell[15047, 437, 313, 9, 48, "Text"],
Cell[CellGroupData[{
Cell[15385, 450, 659, 21, 76, "Input"],
Cell[16047, 473, 985, 33, 117, "Output"]
}, Open  ]],
Cell[17047, 509, 446, 15, 123, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
