(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     21427,        635]
NotebookOptionsPosition[     19714,        579]
NotebookOutlinePosition[     20317,        601]
CellTagsIndexPosition[     20274,        598]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Radiation From a Plane-Parallel Atmosphere **",
 FontSize->24]], "Title",
 CellChangeTimes->{
  3.6701144841567383`*^9, {3.6701160347139177`*^9, 3.670116035211981*^9}, 
   3.67019424558773*^9, 3.6702007410004807`*^9, 3.670364120976672*^9, {
   3.670364408564468*^9, 3.670364409541194*^9}, {3.6737319430594673`*^9, 
   3.673731953686413*^9}}],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"$Line", ":=", "1"}]}], "Input",
 CellChangeTimes->{{3.6702014732074833`*^9, 3.670201485516623*^9}, {
  3.67020152205274*^9, 3.670201530563534*^9}, {3.670284554270102*^9, 
  3.670284568658255*^9}}],

Cell[TextData[{
 StyleBox["Problem",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.67011569685713*^9, 3.6701156986701317`*^9}, 
   3.6702007410009747`*^9}],

Cell[TextData[{
 "Assuming a plane-parallel atmosphere, (1) show that emission lines will \
appear if ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "\[Lambda]"], TraditionalForm]]],
 " >> 1 and there is no radiation entering the atmosphere from outside. (2) \
Further, show that, if radiation enters from below, the relation between \
specific intensity and source function will determine whether emission or \
absorption lines are seen."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670114881468607*^9, 3.6701148979074306`*^9}, {
   3.6701149837486563`*^9, 3.670115072697233*^9}, {3.6701155580988483`*^9, 
   3.670115668844935*^9}, {3.670115723227726*^9, 3.670115723749885*^9}, {
   3.6701160387538443`*^9, 3.6701160390579977`*^9}, {3.670194286929597*^9, 
   3.670194288420822*^9}, 3.670200741003162*^9, {3.6703642354986553`*^9, 
   3.67036423730779*^9}, 3.67036427189014*^9, {3.673731972721971*^9, 
   3.673732032557839*^9}, {3.673737698097097*^9, 3.673737706250186*^9}},
 TextAlignment->Left,
 TextJustification->1,
 LineSpacing->{1, 3}],

Cell[TextData[{
 "\n",
 StyleBox["Hints",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.670117651601288*^9, 3.670117655086029*^9}, 
   3.670200741003615*^9}],

Cell[TextData[{
 "The emergent intensity at the top of the atmosphere is the general solution \
to the transfer equation.\nCalculate the integral in the source function.\nIf \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["B", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " for LTE, then \[Tau] >> 1. Calculate the source function for \[Tau] >> 1 \
and for \[Tau] << 1.\nFind an expression for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["i", 
     RowBox[{"\[Lambda]", ",", "0"}]], " ", "in", " ", "terms", " "}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"],
 "of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["j", "\[Lambda]"], " "}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "and judge whether there will be emission or absorption when ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["j", "\[Lambda]"], TraditionalForm]]],
 "  >> 1."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.6701159257090197`*^9, 3.670116019553904*^9}, {
   3.6701161674607077`*^9, 3.6701162053537273`*^9}, {3.670194372759892*^9, 
   3.670194374153833*^9}, 3.670200741004274*^9, 3.6703642795409603`*^9, {
   3.673732045443129*^9, 3.6737322357014503`*^9}}],

Cell[TextData[{
 StyleBox["\[LineSeparator]", "Input"],
 "\n",
 StyleBox["Useful Equations:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.670116586419656*^9, 3.67011659119991*^9}, {
   3.6701948694882393`*^9, 3.670194893362927*^9}, {3.670195019345068*^9, 
   3.670195063029786*^9}, 3.670195495956923*^9, 3.670195558720975*^9, 
   3.670195654585294*^9, {3.6701961617449093`*^9, 3.670196168444582*^9}, {
   3.6701963733751507`*^9, 3.670196388469788*^9}, 3.670196432118155*^9, 
   3.6702007410289583`*^9, {3.670201009142297*^9, 3.670201011794355*^9}, 
   3.6702836215572166`*^9}],

Cell[BoxData[{
 FormBox[
  RowBox[{
   SubscriptBox["i", "\[Lambda]"], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["i", "\[Lambda]0"], "*", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       SubscriptBox["\[Tau]", "\[Lambda]0"]}]]}], "-", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      SubscriptBox["\[Tau]", 
       RowBox[{"\[Lambda]", ",", "0"}]], "0"], 
     RowBox[{
      SubscriptBox["s", "\[Lambda]"], "*", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SubscriptBox["\[Tau]", "\[Lambda]"]}]], 
      RowBox[{"\[DifferentialD]", 
       SubscriptBox["\[Tau]", "\[Lambda]"]}]}]}]}]}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"equation", " ", "of", " ", "radiative", " ", "transfer"}], 
       ";", 
       RowBox[{"\[Tau]", "=", 
        RowBox[{"optical", " ", "depth"}]}]}], ",", 
      RowBox[{"s", " ", "is", " ", "the", " ", "source", " ", "function"}]}], 
     ")"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Plain",
    FontSlant->"Italic"]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["s", "\[Lambda]"], "=", 
    RowBox[{
     FractionBox[
      SubscriptBox["j", "\[Lambda]"], 
      SubscriptBox["\[Kappa]", "\[Lambda]"]], 
     StyleBox[
      RowBox[{" ", 
       StyleBox[" ",
        FontWeight->"Plain",
        FontSlant->"Italic"]}]], 
     StyleBox[
      RowBox[{"(", 
       RowBox[{"source", " ", "function"}], ")"}],
      FontWeight->"Plain",
      FontSlant->"Italic"]}]}], 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Plain",
    FontSlant->"Italic"]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Tau]", "\[Lambda]0"], "=", 
    RowBox[{
     SubscriptBox["\[Kappa]", "\[Lambda]"], "*", "\[ScriptCapitalL]", "*", 
     "\[Rho]"}]}], " "}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   StyleBox[" ",
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "optical", " ", "depth", " ", "in", " ", "terms", " ", "of", " ", 
       "absorption", " ", "coefficient"}], ",", 
      RowBox[{"actual", " ", "depth"}], ",", 
      RowBox[{"and", " ", "density"}]}], ")"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Plain",
    FontSlant->"Italic"]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["i", "\[Lambda]"], "[", "0", "]"}], "=", 
   RowBox[{
    RowBox[{
     SubscriptBox["i", "\[Lambda]0"], "*", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Kappa]", "\[Lambda]"], "*", "\[ScriptCapitalL]", "*", 
        "\[Rho]"}]}], ")"}]}], "+", 
    RowBox[{
     FormBox[
      SubscriptBox["s", "\[Lambda]"],
      TraditionalForm], "*", 
     FormBox[
      RowBox[{
       SubscriptBox["\[Kappa]", "\[Lambda]"], "*", "\[ScriptCapitalL]", "*", 
       "\[Rho]"}],
      TraditionalForm]}]}]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  StyleBox[
   RowBox[{"(", 
    StyleBox[
     RowBox[{"expression", " ", "for", " ", 
      FormBox[
       SubscriptBox["i", 
        RowBox[{"\[Lambda]", ",", "0"}]],
       TraditionalForm]}],
     FontSlant->"Italic"], ")"}], "Text"], TraditionalForm]}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670024577191853*^9, 3.670024579538969*^9}, {
   3.670024624107288*^9, 3.670024894294174*^9}, {3.670024943774929*^9, 
   3.670024971738525*^9}, {3.67002514435083*^9, 3.670025147795293*^9}, {
   3.6700252139218063`*^9, 3.67002521575095*^9}, 3.6700253017518463`*^9, 
   3.67011654558143*^9, {3.670116606621243*^9, 3.6701166080987053`*^9}, {
   3.6701169543239822`*^9, 3.6701169620530376`*^9}, {3.670118158526649*^9, 
   3.6701181622876673`*^9}, {3.670118408707041*^9, 3.6701184124213877`*^9}, 
   3.6701184475656643`*^9, 3.670200741029684*^9, 3.670201065964548*^9, {
   3.670282905989079*^9, 3.670282965091505*^9}, {3.670283056356124*^9, 
   3.670283075180468*^9}, {3.6702831115502872`*^9, 3.670283427329583*^9}, 
   3.670285389231699*^9, 3.670364303827129*^9, {3.673733337491816*^9, 
   3.673733430072171*^9}, {3.6737338792564087`*^9, 3.673733899473628*^9}, 
   3.6737344057114563`*^9, {3.6737354064563103`*^9, 3.673735409941269*^9}, {
   3.673735675679123*^9, 3.673735688077466*^9}, {3.673735787900325*^9, 
   3.673735802382063*^9}}],

Cell[TextData[{
 StyleBox["\nSolution",
  FontWeight->"Bold"],
 " (1):"
}], "Text",
 CellChangeTimes->{{3.6702835139010363`*^9, 3.670283526046495*^9}, {
  3.670283585590893*^9, 3.670283603757029*^9}, {3.670283793166462*^9, 
  3.6702838015719423`*^9}, {3.670285991308682*^9, 3.6702859926447573`*^9}, {
  3.670364313853258*^9, 3.670364321300959*^9}, {3.673733485143951*^9, 
  3.6737334876134663`*^9}, {3.673737731191102*^9, 3.673737735057617*^9}}],

Cell["\<\
Calculating the integral from the equation for radiative transfer :\
\>", "Text",
 CellChangeTimes->{{3.673733476580225*^9, 3.67373348237787*^9}, {
  3.673733529819683*^9, 3.6737335352444763`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    SubscriptBox["\[Tau]", "\[Lambda]0"], "0"], 
   RowBox[{
    SubscriptBox["s", "\[Lambda]"], "*", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      SubscriptBox["\[Tau]", "\[Lambda]"]}]], 
    RowBox[{"\[DifferentialD]", 
     SubscriptBox["\[Tau]", "\[Lambda]"]}]}]}]}]], "Input",
 CellChangeTimes->{{3.673733910386012*^9, 3.673733914336995*^9}, {
   3.673733966241437*^9, 3.673733996050336*^9}, 3.673734032754262*^9}],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ScriptCapitalL]"}], " ", "\[Kappa]", " ", 
        "\[Rho]"}]]}], ")"}], " ", 
    SubscriptBox["j", "\[Lambda]"]}], 
   SubscriptBox["\[Kappa]", "\[Lambda]"]]}]], "Output",
 CellChangeTimes->{
  3.673733565582706*^9, 3.67373391998598*^9, {3.673733969803931*^9, 
   3.673733999071908*^9}, 3.6737340353467283`*^9, 3.673734937027258*^9, 
   3.673735052638129*^9, 3.673735093102696*^9, 3.673736025319282*^9, 
   3.6737360997856073`*^9}]
}, Open  ]],

Cell["Therefore,", "Text",
 CellChangeTimes->{{3.6737340819936*^9, 3.6737340866417017`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", "\[Lambda]"], "=", 
  RowBox[{
   FractionBox[
    SubscriptBox["i", "\[Lambda]0"], 
    SuperscriptBox["\[ExponentialE]", 
     SubscriptBox["\[Tau]", "\[Lambda]0"]]], "-", 
   RowBox[{
    SubscriptBox["s", "\[Lambda]"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SubscriptBox["\[Tau]", "\[Lambda]0"]}]], "-", "1"}], 
     ")"}]}]}]}]], "Text",
 CellChangeTimes->{{3.673734123385723*^9, 3.6737341647593193`*^9}, 
   3.673734254336389*^9, {3.673734344193466*^9, 3.673734364254182*^9}, 
   3.673734436932411*^9}],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  SubscriptBox["i", "\[Lambda]0"]],
  CellChangeTimes->{{3.673734123385723*^9, 3.6737341647593193`*^9}, 
    3.673734254336389*^9, {3.673734344193466*^9, 3.673734364254182*^9}, 
    3.673734436932411*^9}],
 " = 0 (no radiation is entering from outside), then, in the case where \
\[Tau] >> 1 ( ",
 Cell[BoxData[
  SubscriptBox["s", "\[Lambda]"]],
  CellChangeTimes->{{3.673733910386012*^9, 3.673733914336995*^9}, {
    3.673733966241437*^9, 3.673733996050336*^9}, 3.673734032754262*^9}],
 " = ",
 Cell[BoxData[
  SubscriptBox["b", "\[Lambda]"]],
  CellChangeTimes->{{3.673733910386012*^9, 3.673733914336995*^9}, {
    3.673733966241437*^9, 3.673733996050336*^9}, 3.673734032754262*^9}],
 " for LTE), the exponent is nearly zero, and\n\n",
 Cell[BoxData[
  SubscriptBox["i", "\[Lambda]"]],
  CellChangeTimes->{{3.673734123385723*^9, 3.6737341647593193`*^9}, 
    3.673734254336389*^9, {3.673734344193466*^9, 3.673734364254182*^9}, 
    3.673734436932411*^9}],
 " =",
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["s", "\[Lambda]"]}]],
  CellChangeTimes->{{3.673733910386012*^9, 3.673733914336995*^9}, {
    3.673733966241437*^9, 3.673733996050336*^9}, 3.673734032754262*^9}],
 " =  ",
 Cell[BoxData[
  SubscriptBox["b", "\[Lambda]"]],
  CellChangeTimes->{{3.673733910386012*^9, 3.673733914336995*^9}, {
    3.673733966241437*^9, 3.673733996050336*^9}, 3.673734032754262*^9}],
 "\n\nThe emergent radiation will appear as blackbody radiation. In the case \
where \[Tau] << 1, then ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", 
    RowBox[{"-", "\[Tau]"}]], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " \[TildeEqual] 1 - \[Tau], so"
}], "Text",
 CellChangeTimes->{{3.673734484852336*^9, 3.673734488290114*^9}, {
   3.67373452170223*^9, 3.6737345897908287`*^9}, {3.673734631996743*^9, 
   3.6737347838451433`*^9}, 3.673735026036497*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", "\[Lambda]0"], "\[TildeEqual]", 
  RowBox[{
   RowBox[{"-", 
    SubscriptBox["s", "\[Lambda]"]}], "*", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SubscriptBox["\[Tau]", "\[Lambda]0"], "-", "1"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.673734831848301*^9, 3.673734925053711*^9}, {
  3.673735069960536*^9, 3.673735073261615*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", "\[Lambda]0"], "\[TildeEqual]", 
  FractionBox[
   RowBox[{"\[ScriptCapitalL]", " ", "\[Kappa]", " ", "\[Rho]", " ", 
    SubscriptBox["j", "\[Lambda]"]}], 
   SubscriptBox["\[Kappa]", "\[Lambda]"]]}]], "Output",
 CellChangeTimes->{{3.6737349265612783`*^9, 3.6737349370617228`*^9}, {
   3.6737350314637127`*^9, 3.6737350931313953`*^9}, 3.6737360253524446`*^9, 
   3.673736099819158*^9}]
}, Open  ]],

Cell["For a slab of thickness \[ScriptCapitalL],", "Text",
 CellChangeTimes->{{3.673735134049673*^9, 3.673735145404607*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[Tau]", "\[Lambda]0"], ":=", 
  RowBox[{
  "\[Kappa]", "*", "\[ScriptCapitalL]", "*", "\[Rho]", " "}]}]], "Input",
 CellChangeTimes->{3.6737352160597982`*^9}],

Cell[TextData[{
 "and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "\[Lambda]"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " defined as"
}], "Text",
 CellChangeTimes->{{3.6737352208599653`*^9, 3.6737352590017633`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["s", "\[Lambda]"], ":=", 
  FractionBox[
   SubscriptBox["j", "\[Lambda]"], 
   SubscriptBox["\[Kappa]", "\[Lambda]"]]}]], "Input",
 CellChangeTimes->{3.6737352649900618`*^9}],

Cell["Therefore,", "Text",
 CellChangeTimes->{{3.673735277804892*^9, 3.6737352812434607`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", "\[Lambda]0"], "\[TildeEqual]", 
  RowBox[{
   FractionBox[
    SubscriptBox["j", "\[Lambda]"], 
    SubscriptBox["\[Kappa]", "\[Lambda]"]], "*", " ", 
   SubscriptBox["\[Kappa]", "\[Lambda]"], "*", "\[ScriptCapitalL]", "*", 
   "\[Rho]"}]}]], "Input",
 CellChangeTimes->{{3.6737353227001877`*^9, 3.673735335892474*^9}, {
  3.673735423887375*^9, 3.673735426947768*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["i", "\[Lambda]0"], "\[TildeEqual]", 
  RowBox[{"\[ScriptCapitalL]", " ", "\[Rho]", " ", 
   SubscriptBox["j", "\[Lambda]"]}]}]], "Output",
 CellChangeTimes->{3.6737353374927473`*^9, 3.6737354297981253`*^9, 
  3.6737360254334106`*^9, 3.6737360999010487`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Therefore", ",", 
   RowBox[{
    RowBox[{
    "emission", " ", "lines", " ", "will", " ", "appear", " ", "for", " ", 
     SubscriptBox["j", "\[Lambda]"]}], " ", ">>", " ", "1."}]}], 
  "\n"}]], "Text",
 CellChangeTimes->{{3.673735457851207*^9, 3.673735520284905*^9}}],

Cell[TextData[StyleBox["Solution (2):",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.673737750108645*^9, 3.6737377575316133`*^9}, 
   3.673737916303553*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["i", "\[Lambda]"], "[", "0", "]"}], "==", 
   RowBox[{
    RowBox[{
     SubscriptBox["i", "\[Lambda]0"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{
        SubscriptBox["\[Kappa]", "\[Lambda]"], " ", "\[ScriptCapitalL]", " ", 
        "\[Rho]"}]}], ")"}]}], "+", 
    RowBox[{
     SubscriptBox["s", "\[Lambda]"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", "\[Lambda]"], " ", "\[ScriptCapitalL]", " ", 
       "\[Rho]"}], ")"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    SubscriptBox["i", "\[Lambda]"], "[", "0", "]"}], "==", 
   RowBox[{
    SubscriptBox["i", "\[Lambda]0"], "-", 
    RowBox[{
     SubscriptBox["i", "\[Lambda]0"], 
     SubscriptBox["\[Kappa]", "\[Lambda]"], " ", "\[ScriptCapitalL]", " ", 
     "\[Rho]"}], "+", 
    RowBox[{
     SubscriptBox["s", "\[Lambda]"], " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["\[Kappa]", "\[Lambda]"], " ", "\[ScriptCapitalL]", " ", 
       "\[Rho]"}], ")"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   SubscriptBox["i", "\[Lambda]"], "[", "0", "]"}], "==", 
  RowBox[{
   SubscriptBox["i", "\[Lambda]0"], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["\[Kappa]", "\[Lambda]"], " ", "\[ScriptCapitalL]", " ", 
      "\[Rho]"}], ")"}], "*", 
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["i", "\[Lambda]0"], "-", 
      SubscriptBox["s", "\[Lambda]"]}], ")"}]}]}]}]}], "Text",
 CellChangeTimes->{
  3.673735828045741*^9, 3.67373590153223*^9, {3.6737361387772303`*^9, 
   3.673736382801497*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"If", 
     SubscriptBox["i", "\[Lambda]0"]}], ">", 
    SubscriptBox["s", "\[Lambda]"]}], ",", 
   RowBox[{"then", "absorption", "lines", 
    RowBox[{"willappearinthespectrum", ".", " ", "This"}], " ", "situation", 
    " ", "obtains", " ", "for", " ", "the", " ", 
    RowBox[{"Sun", "'"}], "s", " ", "photosphere"}], ",", 
   RowBox[{"for", 
    RowBox[{"example", "."}]}]}], TraditionalForm]], "Text",
 CellChangeTimes->{{3.673737126561718*^9, 3.673737220286772*^9}, {
  3.673737256247692*^9, 3.673737428711809*^9}, {3.673737939281433*^9, 
  3.67373794242842*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"If", 
     SubscriptBox["i", "\[Lambda]0"]}], "<", 
    SubscriptBox["s", "\[Lambda]"]}], ",", 
   RowBox[{
   "then", " ", "emission", " ", "lines", " ", "will", " ", "appear", " ", 
    "in", " ", "the", " ", 
    RowBox[{"spectrum", ".", " ", "This"}], " ", "situation", " ", "obtains", 
    " ", "for", " ", "the", " ", 
    RowBox[{"Sun", "'"}], "s", " ", "chromosphere"}], ",", 
   RowBox[{"for", 
    RowBox[{"example", "."}]}]}], TraditionalForm]], "Text",
 CellChangeTimes->{{3.673737126561718*^9, 3.673737220286772*^9}, {
  3.673737256247692*^9, 3.673737428711809*^9}, {3.673737481868075*^9, 
  3.673737536047731*^9}, {3.67373794764458*^9, 3.6737379498683453`*^9}}]
}, Open  ]]
},
WindowSize->{740, 599},
WindowMargins->{{Automatic, 269}, {Automatic, 10}},
Magnification->1.25,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 365, 6, 85, "Title"],
Cell[947, 30, 298, 5, 57, "Input"],
Cell[1248, 37, 171, 6, 37, "Text"],
Cell[1422, 45, 1050, 21, 155, "Text"],
Cell[2475, 68, 173, 7, 61, "Text"],
Cell[2651, 77, 1327, 38, 209, "Text"],
Cell[3981, 117, 588, 12, 82, "Text"],
Cell[4572, 131, 4644, 134, 349, "Text"],
Cell[9219, 267, 445, 9, 61, "Text"],
Cell[9667, 278, 207, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[9899, 286, 515, 13, 63, "Input"],
Cell[10417, 301, 634, 17, 63, "Output"]
}, Open  ]],
Cell[11066, 321, 92, 1, 37, "Text"],
Cell[11161, 324, 621, 18, 58, "Text"],
Cell[11785, 344, 1889, 46, 186, "Text"],
Cell[CellGroupData[{
Cell[13699, 394, 379, 10, 36, "Input"],
Cell[14081, 406, 430, 9, 59, "Output"]
}, Open  ]],
Cell[14526, 418, 124, 1, 37, "Text"],
Cell[14653, 421, 199, 5, 36, "Input"],
Cell[14855, 428, 235, 8, 39, "Text"],
Cell[15093, 438, 214, 6, 61, "Input"],
Cell[15310, 446, 94, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[15429, 451, 413, 10, 61, "Input"],
Cell[15845, 463, 297, 6, 36, "Output"]
}, Open  ]],
Cell[16157, 472, 304, 8, 59, "Text"],
Cell[16464, 482, 164, 3, 37, "Text"],
Cell[16631, 487, 1698, 53, 125, "Text"],
Cell[18332, 542, 628, 15, 64, "Text"],
Cell[18963, 559, 735, 17, 64, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
