(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     25391,        747]
NotebookOptionsPosition[     22630,        663]
NotebookOutlinePosition[     23233,        685]
CellTagsIndexPosition[     23190,        682]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Jeans Mass",
 FontSize->24]], "Title",
 CellChangeTimes->{
  3.6701144841567383`*^9, {3.6701160347139177`*^9, 3.670116035211981*^9}, 
   3.67019424558773*^9, 3.6702007410004807`*^9, 3.670364120976672*^9, {
   3.670364408564468*^9, 3.670364409541194*^9}, {3.671570162572651*^9, 
   3.6715701661335773`*^9}}],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"$Line", ":=", "1"}]}], "Input",
 CellChangeTimes->{{3.6702014732074833`*^9, 3.670201485516623*^9}, {
  3.67020152205274*^9, 3.670201530563534*^9}, {3.670284554270102*^9, 
  3.670284568658255*^9}}],

Cell[TextData[StyleBox["Problem:",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.684538435296777*^9, 3.6845384462698936`*^9}}],

Cell[TextData[{
 "Derive  the Jeans-mass formula. Then Calculate the Jeans mass of a typical \
molecular cloud with a temperature of 10 degrees K, a molecular hydrogen \
number density of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "10"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and a corresponding density of 2mH nH2. This problem sheet draws on \
information from Mihos (2005) and Pettini (2014). "
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.671570191992025*^9, 3.671570235398188*^9}, {
  3.671570287102426*^9, 3.671570310512959*^9}, {3.684538220034933*^9, 
  3.684538333036681*^9}, {3.684538379010108*^9, 3.684538389325755*^9}, {
  3.684538571862266*^9, 3.684538587191539*^9}}],

Cell[TextData[StyleBox["Solution:",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.6845386196159477`*^9, 3.6845386341583443`*^9}}],

Cell["\<\
A homogeneous gas cloud, undisturbed by affects to the contrary, will \
collapse under its own weight if its mass exceeds its Jeans mass. Such a \
cloud is said to be virialized, meaning that the virial theorem applies :\
\>", "Text",
 CellFrame->{{0, 0}, {0, 0}},
 CellChangeTimes->{{3.684538575438389*^9, 3.684538575449089*^9}, {
  3.684538644201694*^9, 3.684538659598558*^9}}],

Cell["2*K + U = 0", "Text",
 CellChangeTimes->{{3.671570313483423*^9, 3.6715703252561617`*^9}}],

Cell["\<\
where K is kinetic energy, and U is potential energy. The kinetic energy is\
\>", "Text",
 CellChangeTimes->{{3.671570378193903*^9, 3.671570387320354*^9}, 
   3.671570510489286*^9}],

Cell[BoxData[
 RowBox[{"K", "=", 
  RowBox[{
   RowBox[{"(", 
    FractionBox["3", "2"], ")"}], "*", "k", "*", "T", "*", "N"}]}]], "Text",
 CellChangeTimes->{{3.671570607651219*^9, 3.671570672152212*^9}}],

Cell["\<\
where k is Boltzmann' s constant, T is the temperature in kelvins, and N is \
the number of atoms comprising the cloud. And the potential (gravitational) \
energy is\
\>", "Text",
 CellChangeTimes->{{3.671570667976666*^9, 3.671570693449402*^9}}],

Cell[BoxData[
 RowBox[{"U", "=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"(", 
     FractionBox["3", "5"], ")"}]}], "*", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"G", "*", 
      SuperscriptBox["M", "2"]}], "R"], ")"}]}]}]], "Text",
 CellChangeTimes->{{3.671570437319908*^9, 3.671570495531389*^9}}],

Cell["\<\
Substituting into the virial theorem gives
\
\>", "Text",
 CellChangeTimes->{{3.671570558645397*^9, 3.671570563788188*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", "*", "k", "*", "T", "*", "N"}], "=", 
  RowBox[{
   RowBox[{"(", 
    FractionBox["3", "5"], ")"}], "*", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"G", "*", 
      SuperscriptBox["M", "2"]}], "R"], ")"}]}]}]], "Text",
 CellChangeTimes->{{3.671570737237997*^9, 3.671570765509553*^9}, 
   3.6715708644863653`*^9, {3.67157089587744*^9, 3.6715708968825006`*^9}}],

Cell["\<\
If the cloud obeys this equality, it is virialized and will neither expand \
nor contract. If the kinetic energy is greater than the potential energy, the \
cloud will expand. If the potential energy is greater than the kinetic \
energy, the cloud will contract. So, for contraction, the formula is\
\>", "Text",
 CellChangeTimes->{{3.671570786848613*^9, 3.6715708146176577`*^9}, {
  3.6715708859314938`*^9, 3.671570920570714*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", "*", "k", "*", "T", "*", "N"}], "<", 
  RowBox[{
   RowBox[{"(", 
    FractionBox["3", "5"], ")"}], "*", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"G", "*", 
      SuperscriptBox["M", "2"]}], "R"], ")"}]}]}]], "Text",
 CellChangeTimes->{3.671570916300694*^9}],

Cell["\<\
The number of particles in the cloud is found by dividing the total mass of \
the cloud by the mass of a particle:\
\>", "Text",
 CellChangeTimes->{{3.671570944278632*^9, 3.671570957227138*^9}}],

Cell[BoxData[
 RowBox[{"N", "=", 
  FractionBox["M", 
   RowBox[{"\[Mu]", "*", "m"}]]}]], "Text",
 CellChangeTimes->{{3.6715709825957537`*^9, 3.671571004532835*^9}}],

Cell["\<\
where \[Mu] is the mean molecular weight. Assuming that the cloud is roughly \
spherical, we find its volume by\
\>", "Text",
 CellChangeTimes->{{3.671571020929722*^9, 3.6715710359150047`*^9}, 
   3.671571114259366*^9}],

Cell[BoxData[
 RowBox[{"V", "=", 
  RowBox[{
   FractionBox["4", "3"], "*", "\[Pi]", "*", 
   SuperscriptBox["R", "3"]}]}]], "Text",
 CellChangeTimes->{{3.671571067806426*^9, 3.6715710993955793`*^9}}],

Cell["where", "Text",
 CellChangeTimes->{{3.671571118086488*^9, 3.671571122658291*^9}}],

Cell[BoxData[
 RowBox[{"V", "=", 
  FractionBox["M", "\[Rho]"]}]], "Text",
 CellChangeTimes->{{3.671571126289913*^9, 3.671571147492741*^9}}],

Cell["\<\
where \[Rho] is the density. Substituting:\
\>", "Text",
 CellChangeTimes->{{3.671571160865364*^9, 3.6715711780614567`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["M", "\[Rho]"], "=", 
  RowBox[{
   FractionBox["4", "3"], "*", "\[Pi]", "*", 
   SuperscriptBox["R", "3"]}]}]], "Text",
 CellChangeTimes->{{3.671571199796897*^9, 3.6715712110688553`*^9}}],

Cell["Solve for R:", "Text",
 CellChangeTimes->{{3.671571251718794*^9, 3.671571269746291*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    FractionBox["M", "\[Rho]"], "==", 
    RowBox[{
     FractionBox["4", "3"], "*", "\[Pi]", "*", 
     SuperscriptBox["R", "3"]}]}], ",", "R"}], "]"}]], "Input",
 CellChangeTimes->{{3.671571284415319*^9, 3.671571293758128*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"R", "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["M", 
         RowBox[{"1", "/", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", 
           FractionBox["3", "\[Pi]"]}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"2", "/", "3"}]], " ", 
        SuperscriptBox["\[Rho]", 
         RowBox[{"1", "/", "3"}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox["M", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["3", "\[Pi]"], ")"}], 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[Rho]", 
        RowBox[{"1", "/", "3"}]]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"R", "\[Rule]", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["M", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox["3", "\[Pi]"], ")"}], 
        RowBox[{"1", "/", "3"}]]}], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"2", "/", "3"}]], " ", 
       SuperscriptBox["\[Rho]", 
        RowBox[{"1", "/", "3"}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.671571295064033*^9, 3.671576531090358*^9, 
  3.671576587411635*^9, 3.671577083868444*^9}]
}, Open  ]],

Cell["Rewrite as", "Text",
 CellChangeTimes->{{3.671572524084906*^9, 3.671572534224112*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   FractionBox[
    RowBox[{
     SuperscriptBox["M", 
      RowBox[{"1", "/", "3"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["3", "\[Pi]"], ")"}], 
      RowBox[{"1", "/", "3"}]]}], 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[Rho]", 
      RowBox[{"1", "/", "3"}]]}]], "}"}], "\[Equal]", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox[
     RowBox[{"(", 
      RowBox[{"3", "*", "M"}], ")"}], 
     RowBox[{"(", 
      RowBox[{"4", "*", "\[Pi]", "*", "\[Rho]"}], ")"}]], ")"}], 
   FractionBox["1", "3"]]}]], "Text",
 CellChangeTimes->{{3.6715720041248817`*^9, 3.671572015029582*^9}, {
   3.671572057968346*^9, 3.671572233573344*^9}, {3.671572270639742*^9, 
   3.671572343077147*^9}, {3.671572415961973*^9, 3.6715724289098587`*^9}, 
   3.671572518238098*^9}],

Cell[TextData[{
 "Substitute into the inequality, with N =",
 Cell[BoxData[
  RowBox[{
   RowBox[{"M", "/", "\[Mu]"}], "*", "m"}]],
  CellChangeTimes->{{3.6715709825957537`*^9, 3.671571004532835*^9}}],
 " :"
}], "Text",
 CellChangeTimes->{{3.671571505099962*^9, 3.671571510072173*^9}, {
  3.6715715474837713`*^9, 3.6715715638899527`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", "*", "k", "*", "T", "*", 
   FractionBox["M", 
    RowBox[{"\[Mu]", "*", "m"}]]}], "<", 
  RowBox[{
   RowBox[{"(", 
    FractionBox["3", "5"], ")"}], "*", 
   RowBox[{"(", 
    FractionBox[
     RowBox[{"G", "*", 
      SuperscriptBox["M", "2"]}], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"(", 
         RowBox[{"3", "*", "M"}], ")"}], 
        RowBox[{"(", 
         RowBox[{"4", "*", "\[Pi]", "*", "\[Rho]"}], ")"}]], ")"}], 
      FractionBox["1", "3"]]], ")"}]}]}]], "Text",
 CellChangeTimes->{{3.6715716129852247`*^9, 3.671571652332418*^9}, 
   3.67157170902216*^9, {3.6715718003314238`*^9, 3.6715718080425673`*^9}, {
   3.671571934424448*^9, 3.671571944124242*^9}, {3.671572446749992*^9, 
   3.671572462276263*^9}, 3.671572570212191*^9}],

Cell["Solve for M:", "Text",
 CellChangeTimes->{{3.67157255237787*^9, 3.6715725670277853`*^9}}],

Cell[BoxData[
 RowBox[{"M", ">", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"5", "*", "k", "*", "T"}], 
      RowBox[{"\[Mu]", "*", "m", "*", "G"}]], ")"}], 
    FractionBox["3", "2"]], "*", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["3", 
      RowBox[{"4", "*", "\[Pi]", "*", "\[Rho]"}]], ")"}], 
    FractionBox["1", "2"]]}]}]], "Text",
 CellChangeTimes->{{3.671572643382512*^9, 3.671572830370751*^9}}],

Cell[TextData[{
 "The expression to the right of the inequality sign is known as the Jeans \
mass. If the mass of the cloud is greater than the Jeans mass, the cloud will \
contract, as long as it is not disturbed by external forces such as a nearby \
supernova explosion or strong magnetic fields within the cloud (Mihos, 2005).\
\n\n",
 StyleBox["Example : An Interstellar Molecular Cloud",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Text",
 CellChangeTimes->{{3.6715728716770363`*^9, 3.671572893307232*^9}, 
   3.671572924175432*^9}],

Cell[TextData[{
 StyleBox["Problem",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.67011569685713*^9, 3.6701156986701317`*^9}, 
   3.6702007410009747`*^9}],

Cell[TextData[{
 "A typical interstellar molecular cloud has a temperature (T) of about 10 \
degrees K, a molecular hydrogen number density (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "H2"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ") of about ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "10"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "/",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["m", "3"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", and a corresponding density (\[Rho]) of 2*",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "H"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 "*",
 Cell[BoxData[
  FormBox[
   SubscriptBox["n", "H2"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". The Jeans mass formula can be used to predict whether or not this cloud \
is likely to collapse under its gravity into a protostar. Calculate the Jeans \
mass for such a cloud."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670114881468607*^9, 3.6701148979074306`*^9}, {
   3.6701149837486563`*^9, 3.670115072697233*^9}, {3.6701155580988483`*^9, 
   3.670115668844935*^9}, {3.670115723227726*^9, 3.670115723749885*^9}, {
   3.6701160387538443`*^9, 3.6701160390579977`*^9}, {3.670194286929597*^9, 
   3.670194288420822*^9}, 3.670200741003162*^9, {3.6703642354986553`*^9, 
   3.67036423730779*^9}, 3.67036427189014*^9, {3.6715729454457617`*^9, 
   3.671573037038703*^9}, {3.671573082654632*^9, 3.671573113898616*^9}, {
   3.6715731459105873`*^9, 3.671573155843636*^9}},
 TextAlignment->Left,
 TextJustification->1,
 LineSpacing->{1, 3}],

Cell[TextData[{
 "\n",
 StyleBox["Hint",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.670117651601288*^9, 3.670117655086029*^9}, 
   3.670200741003615*^9, 3.671573187487275*^9}],

Cell["\<\
A cloud that is more massive than its Jeans mass will collapse into a star.\
\>", "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.6701159257090197`*^9, 3.670116019553904*^9}, {
   3.6701161674607077`*^9, 3.6701162053537273`*^9}, {3.670194372759892*^9, 
   3.670194374153833*^9}, 3.670200741004274*^9, 3.6703642795409603`*^9, {
   3.671573178348722*^9, 3.671573190291662*^9}, {3.690500031243091*^9, 
   3.690500038960672*^9}}],

Cell[TextData[{
 StyleBox["\nData:",
  FontWeight->"Bold"],
 " "
}], "Text",
 CellChangeTimes->{{3.670116498485139*^9, 3.67011650847235*^9}, {
  3.6701984616213818`*^9, 3.670198520024919*^9}, {3.670198563639187*^9, 
  3.6701986037224693`*^9}, {3.670198739568869*^9, 3.670198792076078*^9}, {
  3.6701989554658403`*^9, 3.670198992474884*^9}, {3.670199036763496*^9, 
  3.67019904051038*^9}, {3.67019910106606*^9, 3.6701991095912733`*^9}, {
  3.6701991634376917`*^9, 3.670199201418844*^9}, {3.670199242588319*^9, 
  3.6701992561706142`*^9}, {3.67020000197744*^9, 3.6702000127430687`*^9}, {
  3.6702004631704082`*^9, 3.6702005110958147`*^9}, {3.670200562218729*^9, 
  3.670200591999037*^9}, {3.670200741006588*^9, 3.6702007587865877`*^9}}],

Cell[BoxData[
 RowBox[{"k", ":=", 
  RowBox[{"1.38065", "*", 
   RowBox[{"10", "^", 
    RowBox[{"(", 
     RowBox[{"-", "23"}], ")"}], "  ", 
    RowBox[{"(*", 
     RowBox[{"Boltzmann", " ", "constant"}], "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.671573470071362*^9, 3.6715734918448753`*^9}, {
   3.6715736485986977`*^9, 3.671573649386209*^9}, {3.6715762879859877`*^9, 
   3.671576318726447*^9}, 3.671577029050191*^9}],

Cell[BoxData[
 RowBox[{"G", ":=", "6.67428`*^-11", "  ", 
  RowBox[{"(*", 
   RowBox[{"gravitational", " ", "constant"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.671573524854402*^9, 3.6715735289895*^9}, {
   3.6715736384307957`*^9, 3.671573638899314*^9}, {3.6715765603126497`*^9, 
   3.671576572657189*^9}, 3.671577032275762*^9, {3.671577094230576*^9, 
   3.67157710158748*^9}}],

Cell[BoxData[
 RowBox[{"T", ":=", "10", " ", 
  RowBox[{"(*", 
   RowBox[{"temperature", " ", "of", " ", "the", " ", "cloud"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.671573571430069*^9, 3.671573628676688*^9}, {
   3.671576357353549*^9, 3.671576364001116*^9}, 3.671577047544725*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["m", "H"], ":=", "1.673532575215`*^-27", " ", 
  RowBox[{"(*", 
   RowBox[{"mass", " ", "of", " ", "hydrogen", " ", "atom"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.671573678367869*^9, 3.67157375849231*^9}, {
   3.671573844576749*^9, 3.671573892246337*^9}, {3.671576386097478*^9, 
   3.671576394617544*^9}, 3.6715770509171247`*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["n", "H2"], ":=", 
  SuperscriptBox["10", "10"], "  ", 
  RowBox[{"(*", 
   RowBox[{"hydrogen", " ", "density", " ", "in", " ", "the", " ", "cloud"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.671573911305976*^9, 3.671574029537341*^9}, 
   3.67157410220683*^9, {3.6715741543825502`*^9, 3.671574195076107*^9}, 
   3.671574302230749*^9, {3.6715764191707*^9, 3.671576424166437*^9}, 
   3.671577056533369*^9}],

Cell[BoxData[
 RowBox[{"\[Mu]", ":=", "2", "  ", 
  RowBox[{"(*", 
   RowBox[{"mean", " ", "molecular", " ", "weight"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.6715742349449368`*^9, 3.671574244078966*^9}, 
   3.671577059188673*^9}],

Cell[BoxData[
 RowBox[{"\[Rho]", ":=", 
  RowBox[{"\[Mu]", "*", 
   SubscriptBox["m", "H"], "*", 
   SubscriptBox["n", "H2"], "  ", 
   RowBox[{"(*", 
    RowBox[{
    "mass", " ", "density", " ", "of", " ", "the", " ", "hydrogen", " ", 
     "cloud"}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.6715742760010443`*^9, 3.671574328869604*^9}, {
   3.671574365376936*^9, 3.671574371693842*^9}, 3.671577069493438*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["M", "sun"], ":=", 
  RowBox[{"1.99", "*", 
   RowBox[{"10", "^", "30", "  ", 
    RowBox[{"(*", 
     RowBox[{"mass", " ", "of", " ", "Sun"}], "*)"}]}]}]}]], "Input",
 CellChangeTimes->{{3.671574429822976*^9, 3.6715744423307457`*^9}, {
  3.671574515056584*^9, 3.6715745471393747`*^9}, {3.671574636271859*^9, 
  3.6715746588217707`*^9}, {3.671576453578043*^9, 3.671576465525785*^9}, {
  3.6715770793925743`*^9, 3.671577112572447*^9}}],

Cell[TextData[{
 StyleBox["\[LineSeparator]", "Input"],
 "\n",
 StyleBox["Useful Equation:",
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.670116586419656*^9, 3.67011659119991*^9}, {
   3.6701948694882393`*^9, 3.670194893362927*^9}, {3.670195019345068*^9, 
   3.670195063029786*^9}, 3.670195495956923*^9, 3.670195558720975*^9, 
   3.670195654585294*^9, {3.6701961617449093`*^9, 3.670196168444582*^9}, {
   3.6701963733751507`*^9, 3.670196388469788*^9}, 3.670196432118155*^9, 
   3.6702007410289583`*^9, {3.670201009142297*^9, 3.670201011794355*^9}, 
   3.6702836215572166`*^9, 3.6715767488717527`*^9}],

Cell[BoxData[
 RowBox[{"JM", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"5", "*", "k", "*", "T"}], 
      RowBox[{"\[Mu]", "*", "m", "*", "G"}]], ")"}], 
    FractionBox["3", "2"]], "*", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["3", 
      RowBox[{"4", "*", "\[Pi]", "*", "\[Rho]"}]], ")"}], 
    FractionBox["1", "2"]], "  ", 
   RowBox[{"(*", 
    RowBox[{"Jeans", " ", "mass"}], "*)"}]}]}]], "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670024577191853*^9, 3.670024579538969*^9}, {
   3.670024624107288*^9, 3.670024894294174*^9}, {3.670024943774929*^9, 
   3.670024971738525*^9}, {3.67002514435083*^9, 3.670025147795293*^9}, {
   3.6700252139218063`*^9, 3.67002521575095*^9}, 3.6700253017518463`*^9, 
   3.67011654558143*^9, {3.670116606621243*^9, 3.6701166080987053`*^9}, {
   3.6701169543239822`*^9, 3.6701169620530376`*^9}, {3.670118158526649*^9, 
   3.6701181622876673`*^9}, {3.670118408707041*^9, 3.6701184124213877`*^9}, 
   3.6701184475656643`*^9, 3.670200741029684*^9, 3.670201065964548*^9, {
   3.670282905989079*^9, 3.670282965091505*^9}, {3.670283056356124*^9, 
   3.670283075180468*^9}, {3.6702831115502872`*^9, 3.670283427329583*^9}, 
   3.670285389231699*^9, 3.670364303827129*^9, {3.671574734401238*^9, 
   3.671574751835622*^9}}],

Cell[TextData[{
 StyleBox["\nSolution",
  FontWeight->"Bold"],
 " :\n"
}], "Text",
 CellChangeTimes->{{3.6702835139010363`*^9, 3.670283526046495*^9}, {
  3.670283585590893*^9, 3.670283603757029*^9}, {3.670283793166462*^9, 
  3.6702838015719423`*^9}, {3.670285991308682*^9, 3.6702859926447573`*^9}, {
  3.670364313853258*^9, 3.670364321300959*^9}, {3.671574782979145*^9, 
  3.671574783432485*^9}}],

Cell["\<\
Put the appropriate values into the formula and evaluate it :\
\>", "Text",
 CellChangeTimes->{{3.6715747801115303`*^9, 3.671574787434249*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JM", "=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"5", "*", "k", "*", "T"}], 
      RowBox[{"\[Mu]", "*", 
       SubscriptBox["m", "H"], "*", "G"}]], ")"}], 
    FractionBox["3", "2"]], "*", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["3", 
      RowBox[{"4", "*", "\[Pi]", "*", "\[Rho]"}]], ")"}], 
    FractionBox["1", "2"]]}]}]], "Input",
 CellChangeTimes->{{3.671574863721953*^9, 3.6715748651228743`*^9}}],

Cell[BoxData["1.4507785719109353`*^31"], "Output",
 CellChangeTimes->{3.6715760378239317`*^9, 3.671576500588291*^9, 
  3.671576531458254*^9, 3.6715765878781843`*^9, 3.671577084167515*^9}]
}, Open  ]],

Cell["\<\
kilograms. Express the Jeans mass in solar masses:\
\>", "Text",
 CellChangeTimes->{{3.6715766479592733`*^9, 3.671576655557027*^9}, {
  3.671577156481316*^9, 3.67157715840337*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 FractionBox["%", 
  SubscriptBox["M", "sun"]]], "Input",
 CellChangeTimes->{{3.671576673324275*^9, 3.671576688507112*^9}}],

Cell[BoxData["7.290344582467012`"], "Output",
 CellChangeTimes->{3.671576691028319*^9, 3.671577084201507*^9}]
}, Open  ]],

Cell["\<\
We may safely say that, if the molecular cloud is more massive than about 8 \
solar masses (the Jeans mass), it will contract. Such a cloud typically has a \
mass of around 10 solar masses and can, therefore, be expected to contract \
into a protostar (Pettini, 2014).\
\>", "Text",
 CellChangeTimes->{{3.671576710190246*^9, 3.671576726965775*^9}}],

Cell["\<\
References

Pettini, M. (2014). Lecture 11: How do stars form? Structure and Evolution of \
Stars. http://www.ast.cam.ac.uk/~pettini/STARS/Lecture11.pdf (Accessed: \
2016-03-29).

Mihos, C. (2005). Gravitational Collapse of Gas Clouds. \
http://burro.astr.cwru.edu/Academics/Astr221/LifeCycle/jeans.html (Accessed \
2015-08-20).\
\>", "Text",
 CellFrame->0.5,
 CellChangeTimes->{
  3.670117288966044*^9, {3.670117964348548*^9, 3.670117964790057*^9}, 
   3.670200741043264*^9, {3.670285696040897*^9, 3.6702857000468903`*^9}, 
   3.6703643848966837`*^9, {3.6715767849667253`*^9, 3.671576811069397*^9}, 
   3.6715771765450487`*^9}]
}, Open  ]]
},
WindowSize->{740, 599},
WindowMargins->{{266, Automatic}, {Automatic, 24}},
Magnification->1.25,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 330, 6, 85, "Title"],
Cell[912, 30, 298, 5, 57, "Input"],
Cell[1213, 37, 133, 2, 37, "Text"],
Cell[1349, 41, 714, 15, 155, "Text"],
Cell[2066, 58, 136, 2, 37, "Text"],
Cell[2205, 62, 389, 7, 85, "Text"],
Cell[2597, 71, 95, 1, 37, "Text"],
Cell[2695, 74, 191, 4, 37, "Text"],
Cell[2889, 80, 204, 5, 56, "Text"],
Cell[3096, 87, 255, 5, 85, "Text"],
Cell[3354, 94, 306, 10, 62, "Text"],
Cell[3663, 106, 133, 4, 61, "Text"],
Cell[3799, 112, 403, 11, 62, "Text"],
Cell[4205, 125, 441, 7, 109, "Text"],
Cell[4649, 134, 304, 10, 62, "Text"],
Cell[4956, 146, 204, 4, 61, "Text"],
Cell[5163, 152, 165, 4, 58, "Text"],
Cell[5331, 158, 229, 5, 61, "Text"],
Cell[5563, 165, 200, 5, 57, "Text"],
Cell[5766, 172, 87, 1, 37, "Text"],
Cell[5856, 175, 140, 3, 58, "Text"],
Cell[5999, 180, 134, 3, 37, "Text"],
Cell[6136, 185, 226, 6, 59, "Text"],
Cell[6365, 193, 94, 1, 37, "Text"],
Cell[CellGroupData[{
Cell[6484, 198, 290, 8, 61, "Input"],
Cell[6777, 208, 1670, 55, 75, "Output"]
}, Open  ]],
Cell[8462, 266, 92, 1, 37, "Text"],
Cell[8557, 269, 888, 27, 72, "Text"],
Cell[9448, 298, 338, 9, 39, "Text"],
Cell[9789, 309, 820, 23, 102, "Text"],
Cell[10612, 334, 95, 1, 37, "Text"],
Cell[10710, 337, 455, 14, 66, "Text"],
Cell[11168, 353, 559, 12, 160, "Text"],
Cell[11730, 367, 171, 6, 37, "Text"],
Cell[11904, 375, 1602, 42, 159, "Text"],
Cell[13509, 419, 194, 7, 61, "Text"],
Cell[13706, 428, 434, 8, 58, "Text"],
Cell[14143, 438, 734, 13, 61, "Text"],
Cell[14880, 453, 424, 10, 35, "Input"],
Cell[15307, 465, 380, 7, 36, "Input"],
Cell[15690, 474, 289, 6, 35, "Input"],
Cell[15982, 482, 377, 8, 36, "Input"],
Cell[16362, 492, 448, 10, 39, "Input"],
Cell[16813, 504, 234, 5, 36, "Input"],
Cell[17050, 511, 415, 10, 36, "Input"],
Cell[17468, 523, 473, 10, 35, "Input"],
Cell[17944, 535, 611, 12, 82, "Text"],
Cell[18558, 549, 1307, 28, 87, "Text"],
Cell[19868, 579, 396, 9, 85, "Text"],
Cell[20267, 590, 153, 3, 37, "Text"],
Cell[CellGroupData[{
Cell[20445, 597, 486, 15, 67, "Input"],
Cell[20934, 614, 187, 2, 38, "Output"]
}, Open  ]],
Cell[21136, 619, 190, 4, 37, "Text"],
Cell[CellGroupData[{
Cell[21351, 627, 137, 3, 60, "Input"],
Cell[21491, 632, 109, 1, 35, "Output"]
}, Open  ]],
Cell[21615, 636, 358, 6, 109, "Text"],
Cell[21976, 644, 638, 16, 248, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
