(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     82565,       1748]
NotebookOptionsPosition[     79580,       1660]
NotebookOutlinePosition[     80183,       1682]
CellTagsIndexPosition[     80140,       1679]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Pulsating Star ***",
 FontSize->24]], "Title",
 CellChangeTimes->{
  3.6701144841567383`*^9, {3.6701160347139177`*^9, 3.670116035211981*^9}, 
   3.67019424558773*^9, 3.6702007410004807`*^9, 3.670364120976672*^9, {
   3.670364408564468*^9, 3.670364409541194*^9}, {3.673791227011538*^9, 
   3.67379123758069*^9}}],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"$Line", ":=", "1"}]}], "Input",
 CellChangeTimes->{{3.6702014732074833`*^9, 3.670201485516623*^9}, {
  3.67020152205274*^9, 3.670201530563534*^9}, {3.670284554270102*^9, 
  3.670284568658255*^9}}],

Cell[TextData[{
 StyleBox["Problem",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.67011569685713*^9, 3.6701156986701317`*^9}, 
   3.6702007410009747`*^9}],

Cell["\<\
Given the relevant data of a pulsating star, calculate the star\
\[CloseCurlyQuote]s rate of change in surface velocity, radius, and  \
pressure. (This worksheet contains excerpts from Carroll and Ostlie (n.d.). \
See the complete exercise online at \
http://physics.weber.edu/carroll/images/aas00.pdf.)\
\>", "Text",
 CellFrame->0.5,
 CellChangeTimes->{{3.670114881468607*^9, 3.6701148979074306`*^9}, {
   3.6701149837486563`*^9, 3.670115072697233*^9}, {3.6701155580988483`*^9, 
   3.670115668844935*^9}, {3.670115723227726*^9, 3.670115723749885*^9}, {
   3.6701160387538443`*^9, 3.6701160390579977`*^9}, {3.670194286929597*^9, 
   3.670194288420822*^9}, 3.670200741003162*^9, {3.6703642354986553`*^9, 
   3.67036423730779*^9}, 3.67036427189014*^9, 3.673791252104322*^9},
 TextAlignment->Left,
 TextJustification->1,
 LineSpacing->{1, 3}],

Cell[TextData[{
 "\n",
 StyleBox["Hints",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.670117651601288*^9, 3.670117655086029*^9}, 
   3.670200741003615*^9}],

Cell["\<\
Assume a star has its entire mass, M, concentrated in its centre. Its surface \
layers of mass ms << m consist of a thin shell of radius r. Within the shell \
the pressure, P, is everywhere the same. Outside the shell, P is zero. Within \
the star, pressure and radius vary with pulsation. (Figure from Carroll and \
Ostlie (n.d.).)\
\>", "Text",
 CellChangeTimes->{3.673795098532084*^9}],

Cell[BoxData[
 RowBox[{"\n", "           ", 
  RowBox[{
   GraphicsBox[
    TagBox[RasterBox[CompressedData["
1:eJztvV/oVmW+/z0/nx/Nw0TMPtnMiMxmHjEpsCFhBgkDK9K0g83OXxDMnKT2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      "], {{0, 432}, {464, 0}}, {0, 255},
      ColorFunction->RGBColor],
     BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
     Selectable->False],
    BaseStyle->"ImageGraphics",
    ImageSize->{358.75999999999954`, Automatic},
    ImageSizeRaw->{464, 432},
    PlotRange->{{0, 464}, {0, 432}}], "\n"}]}]], "Text",
 CellFrame->{{0, 0}, {0, 0}},
 CellChangeTimes->{{3.670024577191853*^9, 3.670024579538969*^9}, {
   3.670024624107288*^9, 3.670024894294174*^9}, {3.670024943774929*^9, 
   3.670024971738525*^9}, {3.67002514435083*^9, 3.670025147795293*^9}, {
   3.6700252139218063`*^9, 3.67002521575095*^9}, 3.6700253017518463`*^9, 
   3.67011654558143*^9, {3.670116606621243*^9, 3.6701166080987053`*^9}, {
   3.6701169543239822`*^9, 3.6701169620530376`*^9}, {3.670118158526649*^9, 
   3.6701181622876673`*^9}, {3.670118408707041*^9, 3.6701184124213877`*^9}, 
   3.6701184475656643`*^9, 3.670200741029684*^9, 3.670201065964548*^9, {
   3.670282905989079*^9, 3.670282965091505*^9}, {3.670283056356124*^9, 
   3.670283075180468*^9}, {3.6702831115502872`*^9, 3.670283427329583*^9}, 
   3.670285389231699*^9, 3.670364303827129*^9, {3.673792499604376*^9, 
   3.673792564527186*^9}, {3.6737926818834333`*^9, 3.673792693663452*^9}, {
   3.673792760976884*^9, 3.67379293811161*^9}, {3.673792973033485*^9, 
   3.673793292574252*^9}, {3.673793341581058*^9, 3.673793368232497*^9}, {
   3.673793418413772*^9, 3.67379342496391*^9}, {3.6737934579092712`*^9, 
   3.6737934847008133`*^9}, {3.6737935206668987`*^9, 3.673793599196802*^9}, {
   3.673793643572002*^9, 3.673793712876697*^9}, {3.673793757238453*^9, 
   3.673793869398589*^9}, {3.673793906875414*^9, 3.6737939514086123`*^9}, 
   3.6737939986731586`*^9, 3.673795092329167*^9, 3.673884768205677*^9}],

Cell[" By Newton' s second law :", "Text",
 CellChangeTimes->{3.6737940256754503`*^9}],

Cell[BoxData[
 RowBox[{"m", " ", "*", " ", 
  FormBox[
   RowBox[{
    FractionBox["dv", "dt"], "==", 
    RowBox[{
     RowBox[{"4", "*", "\[Pi]", "*", 
      SuperscriptBox["r", "2"], "*", "p"}], "-", 
     FractionBox[
      RowBox[{"g", "*", "M", "*", "m"}], 
      SuperscriptBox["r", "2"]]}]}],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.6737940555800667`*^9, 3.673794071134532*^9}, {
  3.6737941705135183`*^9, 3.673794179724394*^9}, {3.673794227000793*^9, 
  3.673794228993284*^9}, {3.6737960577319927`*^9, 3.673796072436351*^9}}],

Cell["where", "Text",
 CellChangeTimes->{3.673794085783888*^9}],

Cell[BoxData[
 RowBox[{"v", " ", "=", " ", 
  FormBox[
   FractionBox[
    RowBox[{"d", "(", "r", ")"}], "dt"],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.673794189926424*^9, 3.673794190284494*^9}, {
  3.673794235104437*^9, 3.67379426078201*^9}, {3.673796075978894*^9, 
  3.6737960790115547`*^9}}],

Cell["\<\
Assumption of adiabatic expansion and contraction, with initial (i) and final \
(f) values related as follows :\
\>", "Text",
 CellChangeTimes->{3.673794286368216*^9}],

Cell[BoxData[
 RowBox[{
  FormBox[
   RowBox[{
    SubscriptBox["p", "i"], " ", "*", " ", 
    SubsuperscriptBox["v", "i", "\[Gamma]"]}],
   TraditionalForm], "==", 
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SubscriptBox["p", "f"], " ", "*", " ", 
     SubsuperscriptBox["v", "f", "\[Gamma]"]}]}],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.673794328521014*^9, 3.6737943447694902`*^9}}],

Cell["where", "Text",
 CellChangeTimes->{3.673794371248066*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["v", "i", "\[Gamma]"], "=", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox[
     RowBox[{"4", " ", "\[Pi]", " ", 
      SubsuperscriptBox["r", "i", "3"]}], "3"], ")"}], "\[Gamma]"]}]], "Text",\

 CellChangeTimes->{3.673794426008555*^9, 3.673794489403495*^9}],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["v", "f", "\[Gamma]"], "=", 
  SuperscriptBox[
   RowBox[{"(", 
    FractionBox[
     RowBox[{"4", " ", "\[Pi]", " ", 
      SubsuperscriptBox["r", "f", "3"]}], "3"], ")"}], "\[Gamma]"]}]], "Text",\

 CellChangeTimes->{{3.6737944553607883`*^9, 3.673794469212537*^9}, 
   3.673794504914472*^9}],

Cell["Therefore,", "Text",
 CellChangeTimes->{3.673794530761012*^9}],

Cell[BoxData[
 RowBox[{
  FormBox[
   RowBox[{
    SubscriptBox["p", "i"], " ", "*", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox[
       RowBox[{"4", " ", "\[Pi]", " ", 
        SubsuperscriptBox["r", "i", "3"]}], "3"], ")"}], "\[Gamma]"]}],
   TraditionalForm], "=", 
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SubscriptBox["p", "f"], " ", "*", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"4", " ", "\[Pi]", " ", 
         SubsuperscriptBox["r", "f", "3"]}], "3"], ")"}], "\[Gamma]"]}]}],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.673794547963388*^9, 3.673794584121833*^9}, 
   3.673796203151726*^9}],

Cell["and", "Text",
 CellChangeTimes->{{3.673794705623201*^9, 3.673794709510198*^9}}],

Cell[BoxData[
 RowBox[{
  FormBox[
   RowBox[{
    SubscriptBox["p", "i"], " ", "*", 
    SuperscriptBox[
     RowBox[{"(", " ", 
      SubsuperscriptBox["r", "i", "3"], ")"}], "\[Gamma]"]}],
   TraditionalForm], "=", 
  FormBox[
   RowBox[{" ", 
    RowBox[{
     SubscriptBox["p", "f"], " ", "*", " ", 
     SuperscriptBox[
      RowBox[{"(", " ", 
       SubsuperscriptBox["r", "f", "3"], ")"}], "\[Gamma]"]}]}],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.673794736760257*^9, 3.6737947528605022`*^9}, {
   3.673794850421638*^9, 3.67379485914117*^9}, {3.673796211176708*^9, 
   3.6737962137093267`*^9}, 3.673796327371643*^9}],

Cell[BoxData[
 RowBox[{"Solve", " ", "for", " ", 
  RowBox[{
   SubscriptBox["p", "f"], "."}]}]], "Text",
 CellChangeTimes->{{3.673794794922909*^9, 3.6737948111253977`*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["p", "f"], "=", 
  RowBox[{
   SubscriptBox["p", "i"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["r", "i"], 
      SubscriptBox["r", "f"]], ")"}], 
    RowBox[{"3", " ", "\[Gamma]"}]]}]}]], "Text",
 CellChangeTimes->{{3.673794822597577*^9, 3.673794927203704*^9}, {
  3.6737949741351433`*^9, 3.6737950026386957`*^9}}],

Cell["\<\
Use differences instead of differentials in the first two equations :\
\>", "Text",
 CellChangeTimes->{{3.673794956825293*^9, 3.673794964681753*^9}}],

Cell[BoxData[
 RowBox[{"m", " ", "*", " ", 
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SubscriptBox["v", "f"], "-", 
      SubscriptBox["v", "i"]}], "\[CapitalDelta]t"], "==", 
    RowBox[{
     RowBox[{"4", "*", "\[Pi]", "*", 
      SuperscriptBox[
       SubscriptBox["r", "i"], "2"], "*", "p"}], "-", 
     FractionBox[
      RowBox[{"g", "*", "M", "*", "m"}], 
      SuperscriptBox[
       SubscriptBox["r", "i"], "2"]]}]}],
   TraditionalForm]}]], "Text",
 CellChangeTimes->{{3.673795188933441*^9, 3.673795218242968*^9}, {
  3.673795250153617*^9, 3.673795267612163*^9}, {3.6737961036780157`*^9, 
  3.673796118421431*^9}}],

Cell[BoxData[
 RowBox[{"Solve", " ", "for", " ", 
  RowBox[{
   SubscriptBox["v", "f"], "."}]}]], "Text",
 CellChangeTimes->{{3.6737953617763863`*^9, 3.673795383362533*^9}, {
  3.673796128810954*^9, 3.673796129042597*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["v", "f"], "=", 
  RowBox[{
   SubscriptBox["v", "i"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", "*", "p", "*", "\[Pi]", "*", 
        SuperscriptBox[
         SubscriptBox["r", "i"], "2"]}], "m"], "-", 
      FractionBox[
       RowBox[{"g", "*", "M"}], 
       SuperscriptBox[
        SubscriptBox["r", "i"], "2"]]}], ")"}], "*", 
    "\[CapitalDelta]t"}]}]}]], "Text",
 CellChangeTimes->{{3.673795407740947*^9, 3.673795558064527*^9}, 
   3.6737955893207893`*^9, {3.673796126251875*^9, 3.673796145500049*^9}}],

Cell[BoxData[
 RowBox[{"v", "=", 
  FractionBox[
   RowBox[{
    SubscriptBox["r", "f"], "-", 
    SubscriptBox["r", "i"]}], "\[CapitalDelta]t"]}]], "Text",
 CellChangeTimes->{{3.6737956425179987`*^9, 3.673795711869151*^9}, {
  3.6737961483710623`*^9, 3.6737961524751997`*^9}}],

Cell[BoxData[
 RowBox[{"Solve", " ", "for", " ", 
  RowBox[{
   SubscriptBox["r", "f"], "."}]}]], "Text",
 CellChangeTimes->{{3.6737957292261553`*^9, 3.673795745962544*^9}, 
   3.67379615623517*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "f"], "=", 
  RowBox[{
   SubscriptBox["r", "i"], "+", 
   RowBox[{"v", "*", "\[CapitalDelta]t"}]}]}]], "Text",
 CellChangeTimes->{{3.673795752268837*^9, 3.673795791149294*^9}, {
  3.6737961594110193`*^9, 3.673796163866699*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["Data",
  FontWeight->"Bold"],
 ":\n (Relevant data are given in the Solution section, below.)\n"
}], "Text",
 CellChangeTimes->{{3.681684937967408*^9, 3.681684983326186*^9}}],

Cell[TextData[{
 StyleBox["Useful Equations",
  FontWeight->"Bold"],
 ":\nThe following equations, derived above, determine the pressure, \
velocity, and radius pulsation of the star, respectively :"
}], "Text",
 CellChangeTimes->{{3.673795834353407*^9, 3.673795870922925*^9}, {
  3.6737963692941628`*^9, 3.673796372374731*^9}, {3.681684991676591*^9, 
  3.681685001382613*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["p", "f"], "=", 
  RowBox[{
   SubscriptBox["p", "i"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      SubscriptBox["r", "i"], 
      SubscriptBox["r", "f"]], ")"}], 
    RowBox[{"3", " ", "\[Gamma]"}]]}]}]], "Text",
 CellChangeTimes->{3.673795933997221*^9}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["v", "f"], "=", 
  RowBox[{
   SubscriptBox["v", "i"], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"4", "*", "p", "*", "\[Pi]", "*", 
        SuperscriptBox[
         SubscriptBox["r", "i"], "2"]}], "m"], "-", 
      FractionBox[
       RowBox[{"g", "*", "M"}], 
       SuperscriptBox[
        SubscriptBox["r", "i"], "2"]]}], ")"}], "*", 
    "\[CapitalDelta]t"}]}]}]], "Text",
 CellChangeTimes->{{3.6737959558232803`*^9, 3.673795968956938*^9}, 
   3.673796010245573*^9, {3.6737963928145037`*^9, 3.673796396689385*^9}}],

Cell[BoxData[
 RowBox[{
  SubscriptBox["r", "f"], "=", 
  RowBox[{
   SubscriptBox["r", "i"], "+", 
   RowBox[{"v", "*", "\[CapitalDelta]t"}]}]}]], "Text",
 CellChangeTimes->{{3.673796028101625*^9, 3.6737960341791067`*^9}, 
   3.67382199292909*^9}],

Cell[TextData[{
 "ClearAll[\[OpenCurlyDoubleQuote]Global`*\[CloseCurlyDoubleQuote]]\n",
 StyleBox["\[LineSeparator]\nSolution",
  FontWeight->"Bold"],
 " :"
}], "Text",
 CellChangeTimes->{{3.6702835139010363`*^9, 3.670283526046495*^9}, {
  3.670283585590893*^9, 3.670283603757029*^9}, {3.670283793166462*^9, 
  3.6702838015719423`*^9}, {3.670285991308682*^9, 3.6702859926447573`*^9}, {
  3.670364313853258*^9, 3.670364321300959*^9}, {3.673794722849867*^9, 
  3.6737947267406693`*^9}, {3.67382215988799*^9, 3.673822160383485*^9}, {
  3.673823083303144*^9, 3.673823085517591*^9}, {3.681684731232952*^9, 
  3.681684733087562*^9}, {3.681684923492128*^9, 3.681684925469952*^9}}],

Cell["List the relevant data.", "Text",
 CellChangeTimes->{{3.673822143241572*^9, 3.673822157650215*^9}}],

Cell[BoxData[
 RowBox[{"g", ":=", 
  RowBox[{"6.673", "*", 
   SuperscriptBox["10", 
    RowBox[{"-", "11"}]], "  ", 
   RowBox[{"(*", 
    RowBox[{"gravitational", " ", "constant"}], "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.6737913124433327`*^9, 3.673791342591959*^9}, 
   3.673792431776011*^9, 3.674051601995029*^9}],

Cell[BoxData[
 RowBox[{"m", ":=", 
  RowBox[{"1.0", "*", 
   SuperscriptBox["10", "31"], "  ", 
   RowBox[{"(*", 
    RowBox[{"mass", " ", "of", " ", "a", " ", "typical", " ", "Cepheid"}], 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.673791359334928*^9, 3.6737914051182013`*^9}, 
   3.6737924367415247`*^9}],

Cell[BoxData[
 RowBox[{"ms", ":=", 
  RowBox[{"1.0", "*", 
   SuperscriptBox["10", "26"], "  ", 
   RowBox[{"(*", 
    RowBox[{"mass", " ", "of", " ", "surface", " ", "layers"}], 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.67379146005295*^9, 3.6737914933477983`*^9}, 
   3.673792440947101*^9}],

Cell[BoxData[
 RowBox[{"n", ":=", "1"}]], "Input",
 CellChangeTimes->{{3.6739103825895567`*^9, 3.673910384493181*^9}, 
   3.6740529881614*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", "[", "1", "]"}], ":=", 
  RowBox[{"1.70", "*", 
   SuperscriptBox["10", "10"], "  ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"radius", " ", "at", " ", "time"}], "=", "0"}], 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.673792084733186*^9, 3.6737921408263206`*^9}, 
   3.6737924490670137`*^9, 3.673824658005786*^9, {3.673908349604837*^9, 
   3.673908351944524*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"v", "[", "1", "]"}], ":=", "0", " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"initial", " ", "velocity", " ", "at", " ", "time"}], "=", "0"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.673792207520355*^9, 3.673792230466216*^9}, 
   3.673792453187243*^9, 3.673824662027175*^9, {3.673908354648511*^9, 
   3.673908354878607*^9}, {3.673908652814722*^9, 3.67390866430751*^9}, 
   3.6739087031432753`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"p", "[", "1", "]"}], ":=", 
  RowBox[{"5.6", "*", 
   SuperscriptBox["10", "4"], "  ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"initial", " ", "pressure", " ", "at", " ", "time"}], "=", "0"}],
     "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.6737922530450974`*^9, 3.6737923031945457`*^9}, 
   3.673792457146987*^9, {3.6738245404581537`*^9, 3.673824544159154*^9}, {
   3.67382460758389*^9, 3.673824608108889*^9}, {3.673908358999051*^9, 
   3.673908359240601*^9}}],

Cell[BoxData[
 RowBox[{"\[CapitalDelta]t", ":=", 
  SuperscriptBox["10", "4"], "  ", 
  RowBox[{"(*", 
   RowBox[{"time", " ", "interval", " ", "for", " ", "iteration"}], 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.673792323766512*^9, 3.673792367786271*^9}, 
   3.673792462355006*^9}],

Cell[BoxData[
 RowBox[{"\[Gamma]", ":=", 
  FractionBox["5", "3"], "  ", 
  RowBox[{"(*", 
   RowBox[{
   "ratio", " ", "of", " ", "specific", " ", "heats", " ", "for", " ", "a", 
    " ", "monatomic", " ", "gas"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.673792391413643*^9, 3.673792407034135*^9}, 
   3.673792465883073*^9}],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"n", "=", "1"}], ",", 
   RowBox[{"n", "<", "150"}], ",", 
   RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"v", "[", 
      RowBox[{"n", "+", "1"}], "]"}], "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"v", "[", "n", "]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox[
           RowBox[{"4", "*", 
            RowBox[{"p", "[", "n", "]"}], "*", "\[Pi]", "*", 
            SuperscriptBox[
             RowBox[{"r", "[", "n", "]"}], "2"]}], "ms"], "-", 
          FractionBox[
           RowBox[{"g", "*", "m"}], 
           SuperscriptBox[
            RowBox[{"r", "[", "n", "]"}], "2"]]}], ")"}], "*", 
        "\[CapitalDelta]t"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r", "[", 
      RowBox[{"n", "+", "1"}], "]"}], "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"r", "[", "n", "]"}], "+", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"v", "[", 
          RowBox[{"n", "+", "1"}], "]"}], "*", "\[CapitalDelta]t"}], ")"}]}], 
      "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"p", "[", 
      RowBox[{"n", "+", "1"}], "]"}], "=", 
     RowBox[{"N", "[", 
      RowBox[{
       RowBox[{"p", "[", "n", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         FractionBox[
          RowBox[{"r", "[", "n", "]"}], 
          RowBox[{"r", "[", 
           RowBox[{"n", "+", "1"}], "]"}]], ")"}], 
        RowBox[{"3", " ", "\[Gamma]"}]]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"nn", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"n", ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "151"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"vv", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"v", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "151"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"rr", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"r", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "151"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"pp", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"p", "[", "n", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "151"}], "}"}]}], "]"}]}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQPacif9Gm+NeOeq5dYPr8FOVDINpm8t/jIPrUMY5b
INpkfv8jEG2l4/wcRH+bkfwCRH8sOaa5GUhHnDbSAtGXF/+Yux9IF/XKzwfR
m+M8/h0F0hxnr7EeA9JBdb16IJpDZqUBiFZSrjYD0TM/7QDTQhlZkSD6zo7p
USC6wGVFCohm0WkoAtF5YrMqQPQ/plOVIDpjy84mEP3nZ0ILiH6yI60LRMst
desF0Xed/swB0Wsd4uaDaAbFxCUgeoIh63IQzbTPbA+IbhG8fxREfw+/ehpE
20q9Ogui447XPwLRM0wYn4Dd+6bE7DiQZtOpMAfRLs49NiDaw/WWLYgGADxi
tEA=
  "]],

Cell["\<\

Convert time units to days.\
\>", "Text",
 CellChangeTimes->{{3.6740917065108013`*^9, 3.674091712645344*^9}}],

Cell[BoxData[
 RowBox[{"mm", ":=", 
  FractionBox[
   RowBox[{"nn", "*", 
    SuperscriptBox["10", "4"]}], "72000"]}]], "Input",
 CellChangeTimes->{{3.674091615559256*^9, 3.6740916230854807`*^9}, {
  3.674091656531682*^9, 3.674091690570569*^9}, {3.6740917211106043`*^9, 
  3.6740917312792797`*^9}}],

Cell[BoxData[
 RowBox[{"mv", ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"mm", ",", "vv"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6740917573943567`*^9, 3.674091791738385*^9}, {
   3.674091973401867*^9, 3.674091973569188*^9}, 3.674093389131115*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"mv", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Change in Velocity\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", "\"\<velocity\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674093458365076*^9, 3.674093468169313*^9}, {
  3.674093585896401*^9, 3.6740936035528517`*^9}, {3.674093649644823*^9, 
  3.674093760418089*^9}, {3.6740938007996883`*^9, 3.674093807329851*^9}, {
  3.674093846306621*^9, 3.67409384733232*^9}, {3.681686339091083*^9, 
  3.681686345290821*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJw1lAlUU1cax0NBtikpKIjsYUsIiyQBlTrW/FWUKqVKKVQQFEQUFaelU4RR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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"velocity\"", TraditionalForm]},
  AxesOrigin->{0, 0.},
  Method->{},
  PlotLabel->FormBox["\"Change in Velocity\"", TraditionalForm],
  PlotRange->{{0, 20.833333333333332`}, {-25209.37046167694, 
    25208.753450546923`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.41666666666666663`, 0.41666666666666663`}, {
   1008.3624782444773`, 1008.3624782444773`}}]], "Output",
 CellChangeTimes->{
  3.674093815102765*^9, 3.674093852770939*^9, 3.674093907804282*^9, {
   3.674093956386582*^9, 3.674094016925211*^9}, 3.6740940675842113`*^9, 
   3.68168636968473*^9, 3.6816864253259773`*^9, 3.681686463916831*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"mr", ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"mm", ",", "rr"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6740917573943567`*^9, 3.674091791738385*^9}, {
   3.674091973401867*^9, 3.674091973569188*^9}, 3.674093389131115*^9, {
   3.674093880633354*^9, 3.674093884214533*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"mr", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Change in Radius\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", "\"\<radius\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674093458365076*^9, 3.674093468169313*^9}, {
  3.674093585896401*^9, 3.6740936035528517`*^9}, {3.674093649644823*^9, 
  3.674093760418089*^9}, {3.6740938007996883`*^9, 3.674093807329851*^9}, {
  3.674093846306621*^9, 3.67409384733232*^9}, {3.6740938908015537`*^9, 
  3.674093901879612*^9}, {3.681686310892495*^9, 3.6816863266827383`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJw9lQtUk2UYxwFN2YVNVEAuyR0GDHYVKbXv7zBRDFBSaXJRuShqEKioaCqB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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"radius\"", TraditionalForm]},
  AxesOrigin->{0, 1.3376604256142859`*^10},
  Method->{},
  PlotLabel->FormBox["\"Change in Radius\"", TraditionalForm],
  PlotRange->{{0, 20.833333333333332`}, {1.3376604256142859`*^10, 
    1.7003446204368807`*^10}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.41666666666666663`, 0.41666666666666663`}, {
   7.253683896451896*^7, 7.253683896451896*^7}}]], "Output",
 CellChangeTimes->{
  3.6740939078817387`*^9, {3.674093956467046*^9, 3.6740940169887123`*^9}, 
   3.67409406764858*^9, 3.681686369843158*^9, 3.681686425375245*^9, 
   3.681686463996711*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"mp", ":=", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"mm", ",", "pp"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6740917573943567`*^9, 3.674091791738385*^9}, {
   3.674091973401867*^9, 3.674091973569188*^9}, 3.674093389131115*^9, {
   3.67409393023328*^9, 3.674093989273058*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"mp", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Change in Pressure\>\""}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", "\"\<pressure\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.674093458365076*^9, 3.674093468169313*^9}, {
   3.674093585896401*^9, 3.6740936035528517`*^9}, {3.674093649644823*^9, 
   3.674093760418089*^9}, {3.6740938007996883`*^9, 3.674093807329851*^9}, {
   3.674093846306621*^9, 3.67409384733232*^9}, {3.6740939372666473`*^9, 
   3.674093951151361*^9}, {3.681686356107093*^9, 3.681686362005178*^9}, 
   3.681686411685246*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], LineBox[CompressedData["
1:eJw1lglUU2cahhOWqKXDJgoICiEESEBISLTiwNw31JJCbUtRW+2ZaUHGjnUM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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"pressure\"", TraditionalForm]},
  AxesOrigin->{0, 55943.27348996609},
  Method->{},
  PlotLabel->FormBox["\"Change in Pressure\"", TraditionalForm],
  PlotRange->{{0, 20.833333333333332`}, {55943.27348996609, 
    185653.54233307258`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0.41666666666666663`, 0.41666666666666663`}, {
   2594.20537686213, 2594.20537686213}}]], "Output",
 CellChangeTimes->{{3.67409395663953*^9, 3.6740940170550528`*^9}, 
   3.674094067715564*^9, 3.6816863699251747`*^9, 3.6816864254411488`*^9, 
   3.681686464080935*^9}]
}, Open  ]],

Cell["\<\
(from Carroll and Ostlie, , n.d.)

The following diagram shows the magnitude variation of Delta Cephei. Note \
that the increase in magnitude is more rapid than the decrease (Isles, 2010). \
Pulsating stars typically expand faster than they contract. The simplified \
example above does not show this clearly.\
\>", "Text",
 CellChangeTimes->{{3.674094139803649*^9, 3.674094160921322*^9}}],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnX+sXOV55ycJ66n6D6g2ZrdRiO1/NklJScIW3GTR2lmIAiZN1ZqENeAk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    "], {{0, 375}, {280, 
    0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{280, 375},
  PlotRange->{{0, 280}, {0, 375}}]], "Text",
 CellChangeTimes->{3.681686448530291*^9},
 TextAlignment->Center],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.6816863822259274`*^9, 3.681686382252479*^9}}],

Cell[TextData[{
 "References\n\nCarroll, B. and Ostlie, D. (n.d.). Bringing Pulsating Stars \
into the Physics Classroom. http://physics.weber.edu/carroll/images/aas00.pdf \
(Accessed: 2015-09-23).\n\nIsles, J. (2010). The Top 12 Naked-Eye Variable \
Stars. ",
 StyleBox["Sky and Telescope",
  FontSlant->"Italic"],
 ". http://www.skyandtelescope.com/observing/celestial-objects-to-watch/the-\
top-12-naked-eye-variable-stars/ (Accessed: 2015-09-23)."
}], "Text",
 CellFrame->0.5,
 CellChangeTimes->{
  3.670117288966044*^9, {3.670117964348548*^9, 3.670117964790057*^9}, 
   3.670200741043264*^9, {3.670285696040897*^9, 3.6702857000468903`*^9}, 
   3.6703643848966837`*^9, {3.67409419865408*^9, 3.67409420161831*^9}}]
}, Open  ]]
},
WindowSize->{740, 599},
WindowMargins->{{270, Automatic}, {29, Automatic}},
Magnification->1.25,
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, Visible -> False, 
  FrontEndVersion -> 
  "9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, 2013)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 335, 6, 85, "Title"],
Cell[917, 30, 298, 5, 57, "Input"],
Cell[1218, 37, 171, 6, 37, "Text"],
Cell[1392, 45, 849, 16, 130, "Text"],
Cell[2244, 63, 173, 7, 61, "Text"],
Cell[2420, 72, 398, 7, 132, "Text"],
Cell[2821, 81, 23740, 391, 512, "Text"],
Cell[26564, 474, 86, 1, 37, "Text"],
Cell[26653, 477, 548, 14, 59, "Text"],
Cell[27204, 493, 63, 1, 37, "Text"],
Cell[27270, 496, 308, 8, 58, "Text"],
Cell[27581, 506, 177, 4, 61, "Text"],
Cell[27761, 512, 401, 13, 39, "Text"],
Cell[28165, 527, 63, 1, 37, "Text"],
Cell[28231, 530, 307, 9, 69, "Text"],
Cell[28541, 541, 337, 10, 68, "Text"],
Cell[28881, 553, 68, 1, 37, "Text"],
Cell[28952, 556, 669, 22, 69, "Text"],
Cell[29624, 580, 85, 1, 37, "Text"],
Cell[29712, 583, 638, 19, 43, "Text"],
Cell[30353, 604, 173, 4, 36, "Text"],
Cell[30529, 610, 393, 12, 59, "Text"],
Cell[30925, 624, 159, 3, 37, "Text"],
Cell[31087, 629, 643, 19, 60, "Text"],
Cell[31733, 650, 222, 5, 36, "Text"],
Cell[31958, 657, 597, 18, 65, "Text"],
Cell[32558, 677, 277, 7, 53, "Text"],
Cell[32838, 686, 198, 5, 36, "Text"],
Cell[33039, 693, 272, 7, 36, "Text"],
Cell[33314, 702, 208, 6, 109, "Text"],
Cell[33525, 710, 377, 8, 85, "Text"],
Cell[33905, 720, 316, 11, 59, "Text"],
Cell[34224, 733, 599, 18, 65, "Text"],
Cell[34826, 753, 248, 7, 36, "Text"],
Cell[35077, 762, 673, 12, 109, "Text"],
Cell[35753, 776, 105, 1, 37, "Text"],
Cell[35861, 779, 321, 8, 39, "Input"],
Cell[36185, 789, 311, 8, 39, "Input"],
Cell[36499, 799, 298, 8, 39, "Input"],
Cell[36800, 809, 142, 3, 35, "Input"],
Cell[36945, 814, 411, 11, 38, "Input"],
Cell[37359, 827, 440, 10, 36, "Input"],
Cell[37802, 839, 502, 12, 38, "Input"],
Cell[38307, 853, 286, 7, 38, "Input"],
Cell[38596, 862, 327, 8, 58, "Input"],
Cell[38926, 872, 2884, 86, 299, "Input"],
Cell[41813, 960, 120, 4, 61, "Text"],
Cell[41936, 966, 298, 7, 62, "Input"],
Cell[42237, 975, 278, 6, 35, "Input"],
Cell[CellGroupData[{
Cell[42540, 985, 635, 13, 57, "Input"],
Cell[43178, 1000, 3237, 59, 290, "Output"]
}, Open  ]],
Cell[46430, 1062, 328, 7, 35, "Input"],
Cell[CellGroupData[{
Cell[46783, 1073, 681, 13, 57, "Input"],
Cell[47467, 1088, 3136, 58, 292, "Output"]
}, Open  ]],
Cell[50618, 1149, 327, 7, 35, "Input"],
Cell[CellGroupData[{
Cell[50970, 1160, 713, 14, 57, "Input"],
Cell[51686, 1176, 3166, 58, 304, "Output"]
}, Open  ]],
Cell[54867, 1237, 399, 8, 156, "Text"],
Cell[55269, 1247, 23478, 391, 486, "Text"],
Cell[78750, 1640, 94, 1, 35, InheritFromParent],
Cell[78847, 1643, 717, 14, 248, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
